<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\AmcRequest;
use App\Http\Resources\AmcResource;
use App\Models\Amc;
use Illuminate\Http\JsonResponse;

class AmcController extends Controller
{
    protected array $fileFieldNames = ["invoice_copy"];
    protected array $fileFolderPaths = ["invoices"];
    protected array $relations = [
        "company", "service", "client", "amcTasks", "amcTimelines"
    ];

    /**
     * Display a listing of the amcs.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $amcs = Amc::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            AmcResource::collection($amcs)
        );
    }

    /**
     * Store a newly created amc in storage.
     */
    public function store(AmcRequest $request): JsonResponse {
        $amc = new Amc($request->validated());
        $this->storeFiles($request, $amc);
        $amc->save();

        return $this->respondCreated(
            new AmcResource($amc),
            "Amc created successfully!"
        );
    }

    /**
     * Display the specified amc.
     */
    public function show(Amc $amc): JsonResponse {
        $amc->loadMissing($this->relations);

        return $this->respondWithResource(
            new AmcResource($amc),
        );
    }

    /**
     * Update the specified amc in storage.
     */
    public function update(AmcRequest $request, Amc $amc): JsonResponse {
        $amc->fill($request->validated());
        $this->updateFiles($request, $amc);
        $amc->save();

        return $this->respondUpdated(
            new AmcResource($amc),
            "Amc updated successfully!"
        );
    }

    /**
     * Remove the specified amc from storage.
     */
    public function destroy(Amc $amc): JsonResponse {
        // $this->deleteFiles($amc);
        $amc->delete();

        return $this->respondSuccess(
            "Amc deleted successfully!"
        );
    }
}
