<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\AmcTaskRequest;
use App\Http\Resources\AmcTaskResource;
use App\Models\AmcTask;
use Illuminate\Http\JsonResponse;

class AmcTaskController extends Controller
{
    protected array $relations = ["amc", "tasks", "taskLogs"];

    /**
     * Display a listing of the amc tasks.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $amcTasks = AmcTask::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            AmcTaskResource::collection($amcTasks)
        );
    }

    /**
     * Store a newly created amc task in storage.
     */
    public function store(AmcTaskRequest $request): JsonResponse {
        return $this->respondCreated(
            new AmcTaskResource(AmcTask::query()->create($request->validated())),
            "Amc task created successfully!"
        );
    }

    /**
     * Display the specified amc task.
     */
    public function show(AmcTask $amcTask): JsonResponse {
        $amcTask->loadMissing($this->relations);

        return $this->respondWithResource(
            new AmcTaskResource($amcTask),
        );
    }

    /**
     * Update the specified amc task in storage.
     */
    public function update(AmcTaskRequest $request, AmcTask $amcTask): JsonResponse {
        $amcTask->update($request->validated());

        return $this->respondUpdated(
            new AmcTaskResource($amcTask),
            "Amc task updated successfully!"
        );
    }

    /**
     * Remove the specified amc task from storage.
     */
    public function destroy(AmcTask $amcTask): JsonResponse {
        $amcTask->delete();

        return $this->respondSuccess(
            "Amc task deleted successfully!"
        );
    }
}
