<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\AmcTimelineRequest;
use App\Http\Resources\AmcTimelineResource;
use App\Models\AmcTimeline;
use Illuminate\Http\JsonResponse;

class AmcTimelineController extends Controller
{
    protected array $relations = ["amc", "amcTask"];

    /**
     * Display a listing of the amc timelines.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $amcTimelines = AmcTimeline::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            AmcTimelineResource::collection($amcTimelines)
        );
    }

    /**
     * Store a newly created amc timeline in storage.
     */
    public function store(AmcTimelineRequest $request): JsonResponse {
        return $this->respondCreated(
            new AmcTimelineResource(AmcTimeline::query()->create($request->validated())),
            "Amc timeline created successfully!"
        );
    }

    /**
     * Display the specified amc timeline.
     */
    public function show(AmcTimeline $amcTimeline): JsonResponse {
        $amcTimeline->loadMissing($this->relations);

        return $this->respondWithResource(
            new AmcTimelineResource($amcTimeline),
        );
    }

    /**
     * Update the specified amc timeline in storage.
     */
    public function update(AmcTimelineRequest $request, AmcTimeline $amcTimeline): JsonResponse {
        $amcTimeline->update($request->validated());

        return $this->respondUpdated(
            new AmcTimelineResource($amcTimeline),
            "Amc timeline updated successfully"
        );
    }

    /**
     * Remove the specified amc timeline from storage.
     */
    public function destroy(AmcTimeline $amcTimeline): JsonResponse {
        $amcTimeline->delete();

        return $this->respondSuccess(
            "Amc timeline deleted successfully!"
        );
    }
}
