<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\AnswerRequest;
use App\Http\Resources\AnswerResource;
use App\Models\Answer;
use Illuminate\Http\JsonResponse;

class AnswerController extends Controller
{
    /**
     * Display a listing of the answers.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $answers = Answer::query()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            AnswerResource::collection($answers)
        );
    }

    /**
     * Store a newly created answer in storage.
     */
    public function store(AnswerRequest $request): JsonResponse {
        $answer = Answer::query()->create(
            $request->validated() + ["user_id" => auth()->id()]);

        return $this->respondCreated(
            new AnswerResource($answer),
            "Answer created successfully!"
        );
    }

    /**
     * Display the specified answer.
     */
    public function show(Answer $answer): JsonResponse {
        $answer->loadMissing($this->relations);

        return $this->respondWithResource(
            new AnswerResource($answer),
        );
    }

    /**
     * Update the specified answer in storage.
     */
    public function update(AnswerRequest $request, Answer $answer): JsonResponse {
        $answer->update($request->validated());

        return $this->respondUpdated(
            new AnswerResource($answer),
            "Answer updated successfully!"
        );
    }

    /**
     * Remove the specified answer from storage.
     */
    public function destroy(Answer $answer): JsonResponse {
        $answer->delete();

        return $this->respondSuccess(
            "Answer deleted successfully!"
        );
    }
}
