<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\AttendanceRequest;
use App\Http\Resources\AttendanceResource;
use App\Models\Attendance;
use Illuminate\Http\JsonResponse;

class AttendanceController extends Controller
{
    protected array $relations = ["user"];

    /**
     * Display a listing of the attendances.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $attendances = Attendance::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            AttendanceResource::collection($attendances)
        );
    }

    /**
     * Store a newly created attendance in storage.
     */
    public function store(AttendanceRequest $request): JsonResponse {
        return $this->respondCreated(
            new AttendanceResource(Attendance::query()->create($request->all())),
            "Attendance created successfully!"
        );
    }

    /**
     * Display the specified attendance.
     */
    public function show(Attendance $attendance): JsonResponse {
        return $this->respondWithResource(
            new AttendanceResource($attendance)
        );
    }

    /**
     * Update the specified attendance in storage.
     */
    public function update(AttendanceRequest $request, Attendance $attendance): JsonResponse {
        $attendance->update($request->validated());

        return $this->respondUpdated(
            new AttendanceResource($attendance),
            "Attendance updated successfully!"
        );
    }

    /**
     * Remove the specified attendance from storage.
     */
    public function destroy(Attendance $attendance): JsonResponse {
        $attendance->delete();

        return $this->respondSuccess(
            "Attendance deleted successfully!"
        );
    }
}
