<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\Auth\SignInRequest;
use App\Http\Requests\Api\Auth\SignUpRequest;
use App\Http\Resources\UserResource;
use App\Http\Traits\HasApiResponse;
use App\Http\Traits\HasManageFile;
use App\Mail\ForgotPasswordMail;
use App\Models\Role;
use App\Models\User;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Str;

class AuthController extends Controller
{
    use HasManageFile, HasApiResponse;

    public function signUp(SignUpRequest $request): JsonResponse {
        // create new user
        $user = new User($request->all());

        if ($request->input("role_id") == Role::IS_ADMIN) {
            $user["is_admin"] = true;
        }
        $user->save();

        // $user = User::query()->create($request->all())->refresh();

        // create auth token
        // $token = $user->createToken($user->role->name."-token")->plainTextToken;

        return $this->respondSuccess(
            "Signed Up successfully! Please login with your credentials"
        );
    }

    public function signIn(SignInRequest $request): JsonResponse {
        $user = User::query()->where("email", $request->email)->first();

        // check if the user exists and the provided password is correct
        if (!$user || !Hash::check($request->password, $user->password)) {
            return $this->respondUnAuthorized("Invalid credentials!");
        }

        // eager load role and company of the user
        $user->loadMissing("role", "company");

        $user->tokens()->delete();
        // create auth token
        $token = $user->createToken($user->role->name."-token")->plainTextToken;

        return $this->respondAuthenticated(
            $token,
            "Signed in successfully!",
            new UserResource($user),
        );
    }

    public function forgotPassword(Request $request): JsonResponse {
        $request->validate([
            "email" => "required|string|email"
        ]);

        $user = User::query()->where("email", $request->email)->first();

        if (!isset($user)) {
            return $this->respondNotFound("User does not exists");
        }

        $user->forget_password_token = Str::random(32);
        Mail::to($user->email)->send(new ForgotPasswordMail($user));
        $user->save();

        return $this->respondSuccess(
            "Password reset link has been sent to your registered email id.
                        Click on it to reset your password."
        );
    }

    public function updatePassword(Request $request): JsonResponse {
        $user = User::query()->where("forget_password_token", $request->token)->first();

        if (!isset($user)) {
            return response()->json([
                "success" => false,
                "message" => "User does not exists or token expired!"
            ], 422
            );
        }

        $user->update(["password" => $request->password]);

        return response()->json(["success" => 'Password changed successfully!']);
    }

    public function logout(Request $request): JsonResponse {
        $request->user()->tokens()->delete();

        return $this->respondSuccess("Logged out successfully!");
    }
}
