<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\BreakRequest;
use App\Http\Resources\BreakResource;
use App\Models\EmployeeBreak;
use Illuminate\Http\JsonResponse;

class BreakController extends Controller
{
    protected array $relations = ["user"];

    /**
     * Display a listing of the breaks.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $breaks = EmployeeBreak::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            BreakResource::collection($breaks)
        );
    }

    /**
     * Store a newly created break in storage.
     */
    public function store(BreakRequest $request): JsonResponse {
        return $this->respondCreated(
            new BreakResource(EmployeeBreak::query()->create($request->validated())),
            "Break created successfully!"
        );
    }

    /**
     * Display the specified break.
     */
    public function show(EmployeeBreak $break): JsonResponse {
        return $this->respondWithResource(
            new BreakResource($break),
        );
    }

    /**
     * Update the specified break in storage.
     */
    public function update(BreakRequest $request, EmployeeBreak $break): JsonResponse {
        $break->update($request->validated());
        return $this->respondUpdated(
            new BreakResource($break),
            "Break updated successfully!"
        );
    }

    /**
     * Remove the specified break from storage.
     */
    public function destroy(EmployeeBreak $break): JsonResponse {
        $break->delete();

        return $this->respondSuccess(
            "Break deleted successfully!"
        );
    }
}
