<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\CallLogRequest;
use App\Http\Resources\CallLogResource;
use App\Models\CallLog;
use Illuminate\Http\JsonResponse;

class CallLogController extends Controller
{
    protected array $relations = ["company", "client", "user"];

    /**
     * Display a listing of the call logs.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $callLogs = CallLog::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            CallLogResource::collection($callLogs)
        );
    }

    /**
     * Store a newly created call log in storage.
     */
    public function store(CallLogRequest $request): JsonResponse {
        $callLog = CallLog::query()->create($request->validated());

        return $this->respondCreated(
            new CallLogResource($callLog),
            "Call log created successfully!"
        );
    }

    /**
     * Display the specified call log.
     */
    public function show(CallLog $callLog): JsonResponse {
        $callLog->loadMissing($this->relations);

        return $this->respondWithResource(
            new CallLogResource($callLog)
        );
    }

    /**
     * Update the specified call log in storage.
     */
    public function update(CallLogRequest $request, CallLog $callLog): JsonResponse {
        $callLog->update($request->validated());

        return $this->respondUpdated(
            new CallLogResource($callLog),
            "Call log updated successfully!"
        );
    }

    /**
     * Remove the specified call log from storage.
     */
    public function destroy(CallLog $callLog): JsonResponse {
        $callLog->delete();

        return $this->respondSuccess("Call log deleted successfully!");
    }
}
