<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\ClientRequest;
use App\Http\Resources\ClientResource;
use App\Models\Client;
use Illuminate\Http\JsonResponse;

class ClientsController extends Controller
{
    protected array $relations = [
        "company",
        "projects",
        "meetings",
        "amcs",
        "invoices",
        "credentials",
        "followUps"
    ];

    /**
     * Display a listing of the clients.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $clients = Client::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            ClientResource::collection($clients)
        );
    }

    /**
     * Store a newly created client in storage.
     */
    public function store(ClientRequest $request): JsonResponse {
        return $this->respondCreated(
            new ClientResource(Client::query()->create($request->validated())),
            "Client created successfully!"
        );
    }

    /**
     * Display the specified client.
     */
    public function show(Client $client): JsonResponse {
        $client->loadMissing($this->relations);

        return $this->respondUpdated(
            new ClientResource($client),
            "Client updated successfully!",
        );
    }

    /**
     * Update the specified client in storage.
     */
    public function update(ClientRequest $request, Client $client): JsonResponse {
        $client->update($request->validated());

        return $this->respondUpdated(
            new ClientResource($client),
            "Client updated successfully!"
        );
    }

    /**
     * Remove the specified client from storage.
     */
    public function destroy(Client $client): JsonResponse {
        $client->delete();

        return $this->respondSuccess("Client deleted successfully!");
    }
}
