<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\CompanyRequest;
use App\Http\Resources\CompanyResource;
use App\Models\Company;
use Illuminate\Http\JsonResponse;

class CompanyController extends Controller
{
    protected array $fileFieldNames = ["logo", "sign", "stamp"];
    protected array $fileFolderPaths = ["logos", "signs", "stamps"];
    protected array $relations = [
        "services", "clients", "projects", "payments", "notices", "amcs", "invoices",
        "users", "tasks", "meetings", "notifications", "issues", "complaints", "expenses",
        "vendors", "proposals", "leads", "taskLogs", "feedbackForms",
    ];

    /**
     * Display a listing of the companies.
     */
    public function index(): JsonResponse {
        $companies = Company::latest()->get();

        return $this->respondWithResourceCollection(
            CompanyResource::collection($companies)
        );
    }

    /**
     * Store a newly created company in storage.
     */
    public function store(CompanyRequest $request): JsonResponse {
        $company = new Company($request->validated());
        $this->storeFiles($request, $company);
        $company->save();

        return $this->respondCreated(
            new CompanyResource($company),
            "Company created successfully!"
        );
    }

    /**
     * Display the specified company.
     */
    public function show(Company $company): JsonResponse {
        $company->loadMissing($this->relations);

        return $this->respondWithResource(
            new CompanyResource($company)
        );
    }

    /**
     * Update the specified company in storage.
     */
    public function update(CompanyRequest $request, Company $company): JsonResponse {
        $company->fill($request->validated());
        $this->updateFiles($request, $company);
        $company->save();

        return $this->respondUpdated(
            new CompanyResource($company),
            "Company updated successfully!"
        );
    }

    /**
     * Remove the specified company from storage.
     */
    public function destroy(Company $company): JsonResponse {
        // delete all the files related to the current company
        // $this->deleteFiles($company);
        $company->delete();

        return $this->respondSuccess("Company deleted successfully!");
    }
}
