<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\ComplaintRequest;
use App\Http\Resources\ComplaintResource;
use App\Models\Complaint;
use Illuminate\Http\JsonResponse;

class ComplaintController extends Controller
{
    protected array $fileFieldNames = ["file"];
    protected array $fileFolderPaths = ["complaints"];
    protected array $relations = ["company", "user"];

    /**
     * Display a listing of the complaints.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $complaints = Complaint::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            ComplaintResource::collection($complaints)
        );
    }

    /**
     * Store a newly created complaint in storage.
     */
    public function store(ComplaintRequest $request): JsonResponse {
        $complaint = new Complaint($request->validated());
        $this->storeFiles($request, $complaint);
        $complaint->save();

        return $this->respondCreated(
            new ComplaintResource($complaint),
            "Complaint created successfully!"
        );
    }

    /**
     * Display the specified complaint.
     */
    public function show(Complaint $complaint): JsonResponse {
        $complaint->loadMissing($this->relations);

        return $this->respondWithResource(
            new ComplaintResource($complaint)
        );
    }

    /**
     * Update the specified complaint in storage.
     */
    public function update(ComplaintRequest $request, Complaint $complaint): JsonResponse {
        $complaint->fill($request->validated());
        $this->updateFiles($request, $complaint);
        $complaint->save();

        return $this->respondUpdated(
            new ComplaintResource($complaint),
            "Complaint updated successfully!"
        );
    }

    /**
     * Remove the specified complaint from storage.
     */
    public function destroy(Complaint $complaint): JsonResponse {
        // $this->deleteFiles($complaint);
        $complaint->delete();

        return $this->respondSuccess(
            "Complaint deleted successfully!"
        );
    }
}
