<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\CredentialRequest;
use App\Http\Resources\CredentialResource;
use App\Models\Credential;
use Illuminate\Http\JsonResponse;

class CredentialController extends Controller
{
    protected array $relations = ["project", "client"];

    /**
     * Display a listing of the credentials.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $credentials = Credential::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            CredentialResource::collection($credentials)
        );
    }

    /**
     * Store a newly created credential in storage.
     */
    public function store(CredentialRequest $request): JsonResponse {
        $credential = Credential::query()->create($request->validated());

        return $this->respondCreated(
            new CredentialResource($credential),
            "Credential created successfully!"
        );
    }

    /**
     * Display the specified credential.
     */
    public function show(Credential $credential): JsonResponse {
        $credential->loadMissing($this->relations);

        return $this->respondWithResource(
            new CredentialResource($credential)
        );
    }

    /**
     * Update the specified credential in storage.
     */
    public function update(CredentialRequest $request, Credential $credential): JsonResponse {
        $credential->update($request->validated());

        return $this->respondUpdated(
            new CredentialResource($credential),
            "Credential updated successfully!"
        );
    }

    /**
     * Remove the specified credential from storage.
     */
    public function destroy(Credential $credential): JsonResponse {
        $credential->delete();

        return $this->respondSuccess(
            "Credential deleted successfully!"
        );
    }
}
