<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\ExpenseRequest;
use App\Http\Resources\ExpenseResource;
use App\Models\Expense;
use Illuminate\Http\JsonResponse;

class ExpenseController extends Controller
{
    protected array $fileFieldNames = ["file"];
    protected array $fileFolderPaths = ["expenses"];
    protected array $relations = ["company", "expenseType", "vendor", "spentBy"];

    /**
     * Display a listing of the expenses.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $expenses = Expense::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            ExpenseResource::collection($expenses)
        );
    }

    /**
     * Store a newly created expense in storage.
     */
    public function store(ExpenseRequest $request): JsonResponse {
        $expense = new Expense($request->validated());
        $this->storeFiles($request, $expense);
        $expense->save();

        return $this->respondCreated(
            new ExpenseResource($expense),
            "Expense created successfully!"
        );
    }

    /**
     * Display the specified expense.
     */
    public function show(Expense $expense): JsonResponse {
        $expense->loadMissing($this->relations);

        return $this->respondWithResource(
            new ExpenseResource($expense)
        );
    }

    /**
     * Update the specified expense in storage.
     */
    public function update(ExpenseRequest $request, Expense $expense): JsonResponse {
        $expense->fill($request->validated());
        $this->updateFiles($request, $expense);
        $expense->save();

        return $this->respondCreated(
            new ExpenseResource($expense),
            "Expense updated successfully!"
        );
    }

    /**
     * Remove the specified expense from storage.
     */
    public function destroy(Expense $expense): JsonResponse {
        // $this->deleteFiles($expense);
        $expense->delete();

        return $this->respondSuccess(
            "Expense deleted successfully"
        );
    }
}

