<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\ExpenseTypeRequest;
use App\Http\Resources\ExpenseTypeResource;
use App\Models\ExpenseType;
use Illuminate\Http\JsonResponse;

class ExpenseTypeController extends Controller
{
    protected array $relations = ["expenses"];

    /**
     * Display a listing of the expense types.
     */
    public function index(): JsonResponse {
        $expenseTypes = ExpenseType::filter()->latest()->get();

        return $this->respondWithResourceCollection(
            ExpenseTypeResource::collection($expenseTypes)
        );
    }

    /**
     * Store a newly created expense type in storage.
     */
    public function store(ExpenseTypeRequest $request): JsonResponse {
        $expenseType = ExpenseType::query()->create($request->validated());

        return $this->respondCreated(
            new ExpenseTypeResource($expenseType),
            "ExpenseType created successfully!"
        );
    }

    /**
     * Display the specified expense type.
     */
    public function show(ExpenseType $expenseType): JsonResponse {
        return $this->respondWithResource(
            new ExpenseTypeResource($expenseType)
        );
    }

    /**
     * Update the specified expense type in storage.
     */
    public function update(ExpenseTypeRequest $request, ExpenseType $expenseType): JsonResponse {
        $expenseType->update($request->validated());

        return $this->respondCreated(
            new ExpenseTypeResource($expenseType),
            "ExpenseType updated successfully!"
        );
    }

    /**
     * Remove the specified expense type from storage.
     */
    public function destroy(ExpenseType $expenseType): JsonResponse {
        $expenseType->delete();

        return $this->respondSuccess(
            "ExpenseType deleted successfully"
        );
    }
}

