<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\FollowUpRequest;
use App\Http\Resources\FollowUpResource;
use App\Models\FollowUp;
use Illuminate\Http\JsonResponse;

class FollowUpController extends Controller
{
    protected array $relations = ["lead", "client"];

    /**
     * Display a listing of the follow-ups.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $followUps = FollowUp::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            FollowUpResource::collection($followUps)
        );
    }

    /**
     * Store a newly created follow-up in storage.
     */
    public function store(FollowUpRequest $request): JsonResponse {
        $followUp = FollowUp::query()->create($request->validated());

        return $this->respondCreated(
            new FollowUpResource($followUp),
            "FollowUp created successfully!"
        );
    }

    /**
     * Display the specified follow-up.
     */
    public function show(FollowUp $followUp): JsonResponse {
        $followUp->loadMissing($this->relations);

        return $this->respondWithResource(
            new FollowUpResource($followUp)
        );
    }

    /**
     * Update the specified follow-up in storage.
     */
    public function update(FollowUpRequest $request, FollowUp $followUp): JsonResponse {
        $followUp->update($request->validated());

        return $this->respondCreated(
            new FollowUpResource($followUp),
            "FollowUp updated successfully!"
        );
    }

    /**
     * Remove the specified follow-up from storage.
     */
    public function destroy(FollowUp $followUp): JsonResponse {
        $followUp->delete();

        return $this->respondSuccess(
            "FollowUp deleted successfully"
        );
    }
}

