<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\HolidayRequest;
use App\Http\Resources\HolidayResource;
use App\Models\Holiday;
use Illuminate\Http\JsonResponse;

class HolidayController extends Controller
{
    /**
     * Display a listing of the holidays.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $holidays = Holiday::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            HolidayResource::collection($holidays)
        );
    }

    /**
     * Store a newly created holiday in storage.
     */
    public function store(HolidayRequest $request): JsonResponse {
        return $this->respondCreated(
            new HolidayResource(Holiday::query()->create($request->validated())),
            "Holiday created successfully!"
        );
    }

    /**
     * Display the specified holiday.
     */
    public function show(Holiday $holiday): JsonResponse {
        return $this->respondWithResource(
            new HolidayResource($holiday)
        );
    }

    /**
     * Update the specified holiday in storage.
     */
    public function update(HolidayRequest $request, Holiday $holiday): JsonResponse {
        $holiday->update($request->validated());

        return $this->respondCreated(
            new HolidayResource($holiday),
            "Holiday updated successfully!"
        );
    }

    /**
     * Remove the specified holiday from storage.
     */
    public function destroy(Holiday $holiday): JsonResponse {
        $holiday->delete();

        return $this->respondSuccess(
            "Holiday deleted successfully!"
        );
    }
}
