<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\InvoiceDetailRequest;
use App\Http\Resources\InvoiceDetailResource;
use App\Models\InvoiceDetail;
use Illuminate\Http\JsonResponse;

class InvoiceDetailController extends Controller
{
    protected array $relations = ["invoice", "service"];

    /**
     * Display a listing of the invoice details.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $invoiceDetails = InvoiceDetail::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            InvoiceDetailResource::collection($invoiceDetails)
        );
    }

    /**
     * Store a newly created invoice detail in storage.
     */
    public function store(InvoiceDetailRequest $request): JsonResponse {
        return $this->respondCreated(
            new InvoiceDetailResource(InvoiceDetail::query()->create($request->validated())),
            "Invoice detail created successfully"
        );
    }

    /**
     * Display the specified invoice detail.
     */
    public function show(InvoiceDetail $invoiceDetail): JsonResponse {
        $invoiceDetail->loadMissing($this->relations);

        return $this->respondWithResource(
            new InvoiceDetailResource($invoiceDetail),
        );
    }

    /**
     * Update the specified invoice detail in storage.
     */
    public function update(InvoiceDetailRequest $request, InvoiceDetail $invoiceDetail): JsonResponse {
        $invoiceDetail->update($request->validated());

        return $this->respondUpdated(
            new InvoiceDetailResource($invoiceDetail),
            "Invoice detail updated successfully"
        );
    }

    /**
     * Remove the specified invoice detail from storage.
     */
    public function destroy(InvoiceDetail $invoiceDetail): JsonResponse {
        $invoiceDetail->delete();

        return $this->respondSuccess(
            "Invoice detail deleted successfully!"
        );
    }
}
