<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\LeadRequest;
use App\Http\Resources\LeadResource;
use App\Models\Lead;
use Illuminate\Http\JsonResponse;

class LeadController extends Controller
{
    protected array $relations = ["company", "service", "followUps"];

    /**
     * Display a listing of the leads.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $leads = Lead::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            LeadResource::collection($leads)
        );
    }

    /**
     * Store a newly created lead in storage.
     */
    public function store(LeadRequest $request): JsonResponse {
        $lead = Lead::query()->create($request->validated());

        return $this->respondCreated(
            new LeadResource($lead),
            "Lead created successfully!"
        );
    }

    /**
     * Display the specified lead.
     */
    public function show(Lead $lead): JsonResponse {
        $lead->loadMissing($this->relations);

        return $this->respondWithResource(
            new LeadResource($lead)
        );
    }

    /**
     * Update the specified lead in storage.
     */
    public function update(LeadRequest $request, Lead $lead): JsonResponse {
        $lead->update($request->validated());

        return $this->respondCreated(
            new LeadResource($lead),
            "Lead updated successfully!"
        );
    }

    /**
     * Remove the specified lead from storage.
     */
    public function destroy(Lead $lead): JsonResponse {
        $lead->delete();

        return $this->respondSuccess(
            "Lead deleted successfully"
        );
    }
}

