<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\LeaveRequest;
use App\Http\Resources\LeaveResource;
use App\Models\Leave;
use Illuminate\Http\JsonResponse;

class LeaveController extends Controller
{
    protected array $relations = ["user"];

    /**
     * Display a listing of the leaves.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $leaves = Leave::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            LeaveResource::collection($leaves)
        );
    }

    /**
     * Store a newly created leave in storage.
     */
    public function store(LeaveRequest $request): JsonResponse {
        return $this->respondCreated(
            new LeaveResource(Leave::query()->create($request->validated())),
            "Leave created successfully!"
        );
    }

    /**
     * Display the specified leave.
     */
    public function show(Leave $leave): JsonResponse {
        $leave->loadMissing($this->relations);

        return $this->respondWithResource(
            new LeaveResource($leave)
        );
    }

    /**
     * Update the specified leave in storage.
     */
    public function update(LeaveRequest $request, Leave $leave): JsonResponse {
        $leave->update($request->validated());

        return $this->respondUpdated(
            new LeaveResource($leave),
            "Leave updated successfully!"
        );
    }

    /**
     * Remove the specified leave from storage.
     */
    public function destroy(Leave $leave): JsonResponse {
        $leave->delete();

        return $this->respondSuccess(
            "Leave deleted successfully!"
        );
    }
}
