<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\NoticeRequest;
use App\Http\Resources\NoticeResource;
use App\Models\Notice;
use Illuminate\Http\JsonResponse;

class NoticeController extends Controller
{
    protected array $relations = ["company"];

    /**
     * Display a listing of the notices.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $notices = Notice::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            NoticeResource::collection($notices)
        );
    }

    /**
     * Store a newly created notice in storage.
     */
    public function store(NoticeRequest $request): JsonResponse {
        return $this->respondCreated(
            new NoticeResource(Notice::query()->create($request->validated())),
            "Notice created successfully!"
        );
    }

    /**
     * Display the specified notice.
     */
    public function show(Notice $notice): JsonResponse {
        $notice->loadMissing($this->relations);

        return $this->respondWithResource(
            new NoticeResource($notice)
        );
    }

    /**
     * Update the specified notice in storage.
     */
    public function update(NoticeRequest $request, Notice $notice): JsonResponse {
        $notice->update($request->validated());

        return $this->respondUpdated(
            new NoticeResource($notice),
            "Notice updated successfully!"
        );
    }

    /**
     * Remove the specified notice from storage.
     */
    public function destroy(Notice $notice): JsonResponse {
        $notice->delete();

        return $this->respondSuccess(
            "Notice deleted successfully!"
        );
    }
}
