<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\NotificationRequest;
use App\Http\Resources\NotificationResource;
use App\Models\Notification;
use Illuminate\Http\JsonResponse;

class NotificationController extends Controller
{
    protected array $relations = ["company", "user"];

    /**
     * Display a listing of the notifications.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $notifications = Notification::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            NotificationResource::collection($notifications)
        );
    }

    /**
     * Store a newly created notification in storage.
     */
    public function store(NotificationRequest $request): JsonResponse {
        return $this->respondCreated(
            new NotificationResource(Notification::query()->create($request->validated())),
            "Notification created successfully!"
        );
    }

    /**
     * Display the specified notification.
     */
    public function show(Notification $notification): JsonResponse {
        $notification->loadMissing($this->relations);

        return $this->respondWithResource(
            new NotificationResource($notification)
        );
    }

    /**
     * Update the specified notification in storage.
     */
    public function update(NotificationRequest $request, Notification $notification): JsonResponse {
        $notification->update($request->validated());

        return $this->respondUpdated(
            new NotificationResource($notification),
            "Notification updated successfully!"
        );
    }

    /**
     * Remove the specified notification from storage.
     */
    public function destroy(Notification $notification): JsonResponse {
        $notification->delete();

        return $this->respondSuccess(
            "Notification deleted successfully!"
        );
    }
}
