<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\PageRequest;
use App\Http\Resources\PageResource;
use App\Models\Page;
use App\Models\User;
use Illuminate\Http\JsonResponse;

class PageController extends Controller
{
    protected array $relations = ["permissions"];

    /**
     * Display a listing of the pages.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $pages = Page::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            PageResource::collection($pages),
        );
    }

    /**
     * Store a newly created page in storage.
     */
    public function store(PageRequest $request): JsonResponse {
        $page = Page::query()->create($request->validated());

        $users = User::all();
        $users->each(
            fn(User $user) => $user->permissions()->create(["page_id" => $page->id]));

        return $this->respondCreated(
            new PageResource($page),
            "Page created successfully!"
        );
    }

    /**
     * Display the specified page.
     */
    public function show(Page $page): JsonResponse {
        $page->loadMissing($this->relations);

        return $this->respondWithResource(
            new PageResource($page),
        );
    }

    /**
     * Update the specified page in storage.
     */
    public function update(PageRequest $request, Page $page): JsonResponse {
        $page->update($request->validated());

        return $this->respondUpdated(
            new PageResource($page),
            "Page updated successfully!"
        );
    }

    /**
     * Remove the specified page from storage.
     */
    public function destroy(Page $page): JsonResponse {
        $page->delete();

        return $this->respondSuccess(
            "Page deleted successfully!"
        );
    }
}
