<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\PaymentRequest;
use App\Http\Resources\PaymentResource;
use App\Models\Payment;
use Illuminate\Http\JsonResponse;

class PaymentController extends Controller
{
    protected array $fileFieldNames = ["file"];
    protected array $fileFolderPaths = ["payments"];
    protected array $relations = ["company", "invoice"];

    /**
     * Display a listing of the payments.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $payments = Payment::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            PaymentResource::collection($payments),
        );
    }

    /**
     * Store a newly created payment in storage.
     */
    public function store(PaymentRequest $request): JsonResponse {
        $payment = new Payment($request->validated());
        $this->storeFiles($request, $payment);
        $payment->save();

        return $this->respondCreated(
            new PaymentResource($payment),
            "Payment created successfully!"
        );
    }

    /**
     * Display the specified payment.
     */
    public function show(Payment $payment): JsonResponse {
        $payment->loadMissing($this->relations);

        return $this->respondWithResource(
            new PaymentResource($payment),
        );
    }

    /**
     * Update the specified payment in storage.
     */
    public function update(PaymentRequest $request, Payment $payment): JsonResponse {
        $payment->fill($request->validated());
        $this->updateFiles($request, $payment);
        $payment->save();

        return $this->respondUpdated(
            new PaymentResource($payment),
            "Payment updated successfully!"
        );
    }

    /**
     * Remove the specified payment from storage.
     */
    public function destroy(Payment $payment): JsonResponse {
        // $this->deleteFiles($payment);
        $payment->delete();

        return $this->respondSuccess(
            "Payment deleted successfully!"
        );
    }
}
