<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\ProposalRequest;
use App\Http\Resources\ProposalResource;
use App\Models\Proposal;
use Illuminate\Http\JsonResponse;

class ProposalController extends Controller
{
    protected array $fileFieldNames = ["file"];
    protected array $fileFolderPaths = ["proposals"];
    protected array $relations = ["company", "service"];

    /**
     * Display a listing of the proposals.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $proposals = Proposal::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            ProposalResource::collection($proposals)
        );
    }

    /**
     * Store a newly created proposal in storage.
     */
    public function store(ProposalRequest $request): JsonResponse {
        $proposal = new Proposal($request->validated());
        $this->updateFiles($request, $proposal);
        $proposal->save();

        return $this->respondCreated(
            new ProposalResource($proposal),
            "Proposal created successfully!"
        );
    }

    /**
     * Display the specified proposal.
     */
    public function show(Proposal $proposal): JsonResponse {
        $proposal->loadMissing($this->relations);

        return $this->respondWithResource(
            new ProposalResource($proposal)
        );
    }

    /**
     * Update the specified proposal in storage.
     */
    public function update(ProposalRequest $request, Proposal $proposal): JsonResponse {
        $proposal->fill($request->validated());
        $this->updateFiles($request, $proposal);
        $proposal->save();

        return $this->respondCreated(
            new ProposalResource($proposal),
            "Proposal updated successfully!"
        );
    }

    /**
     * Remove the specified proposal from storage.
     */
    public function destroy(Proposal $proposal): JsonResponse {
        // $this->deleteFiles($proposal);
        $proposal->delete();

        return $this->respondSuccess(
            "Proposal deleted successfully"
        );
    }
}

