<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\QuestionRequest;
use App\Http\Resources\QuestionResource;
use App\Models\Question;
use Illuminate\Http\JsonResponse;

class QuestionController extends Controller
{
    protected array $relations = ["feedbackForm"];

    // Display a listing of the questions.
    public function index(): JsonResponse {
        $page = request()->query("page");

        $questions = Question::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            QuestionResource::collection($questions),
        );
    }

    // Store a newly created question in storage.
    public function store(QuestionRequest $request): JsonResponse {
        $question = Question::query()->create($request->validated());

        return $this->respondCreated(
            new QuestionResource($question),
            "Question created successfully!"
        );
    }

    /**
     * Display the specified question.
     */
    public function show(Question $question): JsonResponse {
        $question->loadMissing($this->relations);

        return $this->respondWithResource(
            new QuestionResource($question)
        );
    }

    /**
     * Update the specified question in storage.
     */
    public function update(QuestionRequest $request, Question $question): JsonResponse {
        $question->update($request->validated());

        return $this->respondUpdated(
            new QuestionResource($question),
            "Question updated successfully!"
        );
    }

    /**
     * Remove the specified question from storage.
     */
    public function destroy(Question $question): JsonResponse {
        $question->delete();

        return $this->respondSuccess(
            "Question deleted successfully!"
        );
    }
}
