<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\RatingRequest;
use App\Http\Resources\RatingResource;
use App\Models\Rating;
use Illuminate\Http\JsonResponse;

class RatingController extends Controller
{
    protected array $relations = ["user", "rater"];

    /**
     * Display a listing of the ratings.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $ratings = Rating::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            RatingResource::collection($ratings)
        );
    }

    /**
     * Store a newly created rating in storage.
     */
    public function store(RatingRequest $request): JsonResponse {
        return $this->respondCreated(
            new RatingResource(Rating::query()->create($request->validated())),
            "Rating created successfully!"
        );
    }

    /**
     * Display the specified rating.
     */
    public function show(Rating $rating): JsonResponse {
        return $this->respondWithResource(
            new RatingResource($rating->loadMissing("rater"))
        );
    }

    /**
     * Update the specified rating in storage.
     */
    public function update(RatingRequest $request, Rating $rating): JsonResponse {
        $rating->update($request->validated());

        return $this->respondUpdated(
            new RatingResource($rating),
            "Rating updated successfully!"
        );
    }

    /**
     * Remove the specified rating from storage.
     */
    public function destroy(Rating $rating): JsonResponse {
        $rating->delete();
        return $this->respondSuccess(
            "Rating deleted successfully!"
        );
    }
}
