<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\RoleRequest;
use App\Http\Resources\RoleResource;
use App\Models\Role;
use Illuminate\Http\JsonResponse;

class RoleController extends Controller
{
    protected array $relations = ["users"];

    /**
     * Display a listing of the roles.
     */
    public function index(): JsonResponse {
        return $this->respondWithResourceCollection(
            RoleResource::collection(Role::all())
        );
    }

    /**
     * Store a newly created role in storage.
     */
    public function store(RoleRequest $request): JsonResponse {
        return $this->respondCreated(
            new RoleResource(Role::query()->create($request->validated())),
            "Role created successfully!"
        );
    }

    /**
     * Display the specified role.
     */
    public function show(Role $role): JsonResponse {
        return $this->respondWithResource(
            new RoleResource($role)
        );
    }

    /**
     * Update the specified role in storage.
     */
    public function update(RoleRequest $request, Role $role): JsonResponse {
        $role->update($request->validated());

        return $this->respondUpdated(
            new RoleResource($role),
            "Role updated successfully!"
        );
    }

    /**
     * Remove the specified role from storage.
     */
    public function destroy(Role $role): JsonResponse {
        $user = auth()->user();
        if (!$user->role_id == Role::IS_ADMIN) {
            return $this->respondForbidden("You don't have permissions!");
        }
        $role->delete();

        return $this->respondSuccess("Role deleted successfully!");
    }
}
