<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\ServiceRequest;
use App\Http\Resources\ServiceResource;
use App\Models\Service;
use Illuminate\Http\JsonResponse;

class ServiceController extends Controller
{
    protected array $fileFieldNames = ["image"];
    protected array $fileFolderPaths = ["services"];
    protected array $relations = [
        "company", "projects", "amcs", "proposals", "leads", "vendors"
    ];

    /**
     * Display a listing of the services.
     */
    public function index(): JsonResponse {
        $services = Service::all();

        return $this->respondWithResourceCollection(
            ServiceResource::collection($services)
        );
    }

    /**
     * Store a newly created service in storage.
     */
    public function store(ServiceRequest $request): JsonResponse {
        $service = new Service($request->validated());
        $this->storeFiles($request, $service);
        $service->save();

        return $this->respondCreated(
            new ServiceResource($service),
            "Services created successfully!"
        );
    }

    /**
     * Display the specified service.
     */
    public function show(Service $service): JsonResponse {
        $service->loadMissing($this->relations);
        return $this->respondWithResource(
            new ServiceResource($service)
        );
    }

    /**
     * Update the specified service in storage.
     */
    public function update(ServiceRequest $request, Service $service): JsonResponse {
        $service->fill($request->validated());
        $this->updateFiles($request, $service);
        $service->save();

        return $this->respondUpdated(
            new ServiceResource($service),
            "Services created successfully!"
        );
    }

    /**
     * Remove the specified service from storage.
     */
    public function destroy(Service $service): JsonResponse {
        // $this->deleteFiles($service);
        $service->delete();

        return $this->respondSuccess("Services deleted successfully!");
    }
}
