<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\TaskLogRequest;
use App\Http\Resources\TaskLogResource;
use App\Models\TaskLog;
use Illuminate\Http\JsonResponse;

class TaskLogController extends Controller
{
    protected array $relations = ["company", "project", "amcTask"];

    /**
     * Display a listing of the taskLogs.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $taskLogs = TaskLog::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            TaskLogResource::collection($taskLogs)
        );
    }

    /**
     * Store a newly created taskLog in storage.
     */
    public function store(TaskLogRequest $request): JsonResponse {
        return $this->respondCreated(
            new TaskLogResource(TaskLog::query()->create($request->validated())),
            "TaskLog created successfully!"
        );
    }

    /**
     * Display the specified taskLog.
     */
    public function show(TaskLog $taskLog): JsonResponse {
        return $this->respondWithResource(
            new TaskLogResource($taskLog->loadMissing($this->relations))
        );
    }

    /**
     * Update the specified taskLog in storage.
     */
    public function update(TaskLogRequest $request, TaskLog $taskLog): JsonResponse {
        $taskLog->update($request->validated());

        return $this->respondUpdated(
            new TaskLogResource($taskLog),
            "TaskLog updated successfully!"
        );
    }

    /**
     * Remove the specified taskLog from storage.
     */
    public function destroy(TaskLog $taskLog): JsonResponse {
        $taskLog->delete();
        return $this->respondSuccess(
            "TaskLog deleted successfully!"
        );
    }
}
