<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\UserRequest;
use App\Http\Resources\UserResource;
use App\Models\User;
use Illuminate\Http\JsonResponse;

class UserController extends Controller
{
    protected array $fileFieldNames = [
        "profile",
        "offer_letter",
        "aadhar_front",
        "aadhar_back",
        "pan",
        "prev_experience_letter",
        "relieving_letter",
    ];
    protected array $fileFolderPaths = [
        "profiles",
        "offer-letters",
        "aadhar-fronts",
        "aadhar-backs",
        "pan-cards",
        "prev-experience-letters",
        "relieving_letters",
    ];
    protected array $relations = [
        "role", "company", "notifications", "leaves", "ratings", "attendances",
        "breaks", "complaints", "meetings", "projects", "tasks", "expenses",
        "issues", "answers", "feedbacks", "permissions"
    ];

    /**
     * Display a listing of the users.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $users = User::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            UserResource::collection($users),
        );
    }

    /**
     * Store a newly created user in storage.
     */
    public function store(UserRequest $request): JsonResponse {
        $user = new User($request->validated());
        $request->has("password") && $user->password = $request->input("password");
        $this->storeFiles($request, $user);
        $user->save();

        return $this->respondCreated(
            new UserResource($user),
            "User created successfully!"
        );
    }

    /**
     * Display the specified user.
     */
    public function show(User $user): JsonResponse {
        $user->loadMissing($this->relations);

        return $this->respondWithResource(
            new UserResource($user),
        );
    }

    /**
     * Update the specified user in storage.
     */
    public function update(UserRequest $request, User $user): JsonResponse {
        $user->fill($request->validated());
        $request->has("password") && $user->password = $request->input("password");
        $this->updateFiles($request, $user);
        $user->save();

        return $this->respondUpdated(
            new UserResource($user),
            "User updated successfully!"
        );
    }

    /**
     * Remove the specified user from storage.
     */
    public function destroy(User $user): JsonResponse {
        // $this->deleteFiles($user);
        $user->delete();

        return $this->respondSuccess(
            "User deleted successfully!",
        );
    }

    public function profile(): JsonResponse {
        return $this->respondWithResource(
            new UserResource(auth()->user())
        );
    }
}
