<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\VendorRequest;
use App\Http\Resources\VendorResource;
use App\Models\Vendor;
use Illuminate\Http\JsonResponse;

class VendorController extends Controller
{
    protected array $relations = ["company", "service", "expenses"];

    /**
     * Display a listing of the vendors.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $vendors = Vendor::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            VendorResource::collection($vendors)
        );
    }

    /**
     * Store a newly created vendor in storage.
     */
    public function store(VendorRequest $request): JsonResponse {
        $vendor = Vendor::query()->create($request->validated());

        return $this->respondCreated(
            new VendorResource($vendor),
            "Vendor created successfully!"
        );
    }

    /**
     * Display the specified vendor.
     */
    public function show(Vendor $vendor): JsonResponse {
        return $this->respondWithResource(
            new VendorResource($vendor->loadMissing("rater"))
        );
    }

    /**
     * Update the specified vendor in storage.
     */
    public function update(VendorRequest $request, Vendor $vendor): JsonResponse {
        $vendor->update($request->validated());

        return $this->respondUpdated(
            new VendorResource($vendor),
            "Vendor updated successfully!"
        );
    }

    /**
     * Remove the specified vendor from storage.
     */
    public function destroy(Vendor $vendor): JsonResponse {
        $vendor->delete();

        return $this->respondSuccess(
            "Vendor deleted successfully!"
        );
    }
}
