<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Api\VendorTransactionRequest;
use App\Http\Resources\VendorTransactionResource;
use App\Models\VendorTransaction;
use Illuminate\Http\JsonResponse;

class VendorTransactionController extends Controller
{
    protected array $relations = ["vendor"];

    /**
     * Display a listing of the vendorTransactions.
     */
    public function index(): JsonResponse {
        $page = request()->query("page");

        $vendorTransactions = VendorTransaction::filter()
            ->latest()
            ->when($page,
                fn($query) => $query->paginate(request()->query("perPage")),
                fn($query) => $query->get()
            );

        return $this->respondWithResourceCollection(
            VendorTransactionResource::collection($vendorTransactions)
        );
    }

    /**
     * Store a newly created vendorTransaction in storage.
     */
    public function store(VendorTransactionRequest $request): JsonResponse {
        $vendorTransaction = VendorTransaction::query()->create($request->validated());

        return $this->respondCreated(
            new VendorTransactionResource($vendorTransaction),
            "VendorTransaction created successfully!"
        );
    }

    /**
     * Display the specified vendorTransaction.
     */
    public function show(VendorTransaction $vendorTransaction): JsonResponse {
        $vendorTransaction->loadMissing($this->relations);

        return $this->respondWithResource(
            new VendorTransactionResource($vendorTransaction)
        );
    }

    /**
     * Update the specified vendorTransaction in storage.
     */
    public function update(VendorTransactionRequest $request, VendorTransaction $vendorTransaction): JsonResponse {
        $vendorTransaction->update($request->validated());

        return $this->respondUpdated(
            new VendorTransactionResource($vendorTransaction),
            "VendorTransaction updated successfully!"
        );
    }

    /**
     * Remove the specified vendorTransaction from storage.
     */
    public function destroy(VendorTransaction $vendorTransaction): JsonResponse {
        $vendorTransaction->delete();

        return $this->respondSuccess(
            "VendorTransaction deleted successfully!"
        );
    }
}
