<?php

namespace App\Http\Controllers;

use App\Http\Traits\HasApiResponse;
use App\Http\Traits\HasManageFile;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Http\Request;

abstract class Controller
{
    use HasApiResponse, HasManageFile;

    protected array $fileFieldNames = [];

    protected array $fileFolderPaths = [];

    protected array $relations = [];

    protected function storeFiles(Request $request, Model $model): void {
        foreach ($this->fileFieldNames as $i => $fieldName) {
            if ($request->hasFile($fieldName)) {
                $model[$fieldName] = $this->storeFile($request, $fieldName, $this->fileFolderPaths[$i]);
            }
        }
    }

    protected function updateFiles(Request $request, Model $model): void {
        foreach ($this->fileFieldNames as $i => $fieldName) {
            if ($request->hasFile($fieldName)) {
                $this->deleteFile($this->fileFolderPaths[$i], $model[$fieldName]);
                $model[$fieldName] = $this->storeFile($request, $fieldName, $this->fileFolderPaths[$i]);
            }
        }
    }

    protected function deleteFiles(Model $model): void {
        foreach ($this->fileFieldNames as $i => $fieldName) {
            $this->deleteFile($this->fileFolderPaths[$i], $model[$fieldName]);
        }
    }
}
