<?php

namespace App\Http\Requests\Api;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class ClientRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array {
        $rules = [
            // relations
            "company_id" => "required|exists:companies,id",

            "name" => "required|string|max:100",
            "company_name" => "required|string|max:100",
            "billing_name" => "sometimes|string|max:100",
            "email" => "required|email|unique:clients|max:255",
            "phone_number" => "required|string|max:20",
            "gst_no" => "required|string|max:20",
            "dob" => "sometimes|date",
            "latitude" => "sometimes|numeric|between:-90,90",
            "longitude" => "sometimes|numeric|between:-180,180",
        ];

        if ($this->routeIs("clients.update")) {
            $clientId = $this->route("client");

            $rules["company_id"] = "sometimes|exists:companies,id";
            $rules["name"] = "sometimes|string|max:255";
            $rules["company_name"] = "sometimes|string|max:255";
            $rules["email"] = [
                "sometimes",
                "email",
                "max:255",
                Rule::unique('clients')->ignore($clientId)
            ];
            $rules["phone_number"] = "sometimes|string|max:20";
            $rules["gst_no"] = "sometimes|string|max:20";
        }

        return $rules;
    }
}
