<?php

namespace App\Http\Requests\Api;

use Illuminate\Foundation\Http\FormRequest;

class CompanyRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array {
        $rules = [
            'name' => 'required|string|max:100',
            'founder_name' => 'required|string|max:100',
            'gst_no' => 'required|string|max:50',
            'address' => 'required|string|max:255',
            'anniversary_date' => 'sometimes|date',

            // bank details
            'bank_name' => 'sometimes|string|max:100',
            'branch_name' => 'sometimes|string|max:50',
            'account_no' => 'sometimes|string|max:50',
            'ifsc_code' => 'sometimes|string|max:20',

            // file uploads
            'logo' => 'sometimes|file|mimes:jpg,jpeg,png|max:2048',
            'stamp' => 'sometimes|file|mimes:jpg,jpeg,png|max:2048',
            'sign' => 'sometimes|file|mimes:jpg,jpeg,png|max:2048',
        ];

        if (request()->routeIs("companies.update")) {
            $rules['name'] = 'sometimes|string|max:255';
            $rules['founder_name'] = 'sometimes|string|max:255';
            $rules['gst_no'] = 'sometimes|string|max:50';
            $rules['address'] = 'sometimes|string|max:255';
            $rules["logo"] = $this->hasFile("logo")
                ? "nullable|file|mimes:jpg,jpeg,png,pdf|max:2048"
                : "nullable|string|max:100";
            $rules["stamp"] = $this->hasFile("stamp")
                ? "nullable|file|mimes:jpg,jpeg,png,pdf|max:2048"
                : "nullable|string|max:100";
            $rules["sign"] = $this->hasFile("sign")
                ? "nullable|file|mimes:jpg,jpeg,png,pdf|max:2048"
                : "nullable|string|max:100";
        }

        return $rules;
    }
}
