<?php

namespace App\Http\Requests\Api;

use Illuminate\Foundation\Http\FormRequest;

class ExpenseRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array {
        $rules = [
            "company_id" => "required|exists:companies,id",
            "expense_type_id" => "required|exists:expense_types,id",
            "vendor_id" => "nullable|exists:vendors,id",
            "user_id" => "nullable|exists:users,id",

            "name" => "required|string|max:100",
            "amount" => "required|numeric|between:0,99999999.99",
            "is_approved" => "required|boolean",
            "file" => "nullable|file|mimes:jpeg,jpg,png,pdf|max:2048",
        ];

        if ($this->routeIs("expenses.update")) {
            $rules["company_id"] = "sometimes|exists:companies,id";
            $rules["expense_type_id"] = "sometimes|exists:expense_types,id";

            $rules["name"] = "sometimes|string|max:100";
            $rules["amount"] = "sometimes|numeric|between:0,99999999.99";
            $rules["is_approved"] = "sometimes|boolean";

            $rules["file"] = $this->hasFile("file")
                ? "nullable|file|mimes:jpg,jpeg,png,pdf|max:2048"
                : "nullable|string|max:100";
        }

        return $rules;
    }
}
