<?php

namespace App\Http\Requests\Api;

use App\Models\Question;
use App\Models\Role;
use Illuminate\Foundation\Http\FormRequest;

class FeedbackFormRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool {
        return in_array(auth()->user()->role_id, [Role::IS_ADMIN, Role::IS_HR]);
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array {
        $questionTypes = Question::TYPES;
        $rules = [
            "company_id" => "required|exists:companies,id",
            "title" => "required|string|max:100",
            "description" => "nullable|string|max:255",
            "start_date" => "required|date",
            "end_date" => "required|date",

            // Validation for questions is conditional (only applied if questions are provided)
            'questions' => 'nullable|array|min:1',
            // question field is required if questions array has at least one entry
            'questions.*.question' => 'required:questions|string|max:255',
            // type is required if questions array has at least one entry
            'questions.*.type' => 'required|in:'.implode(",", $questionTypes),

            // If the question is multiple choice, options are required
            'questions.*.options' => "required_if:questions.*.type,{$questionTypes[0]}|nullable|array|min:2",
            'questions.*.options.*' => "string|max:255",
        ];

        if ($this->routeIs("feedback-forms.update")) {
            $rules["title"] = "sometimes|string|max:100";
            $rules['questions'] = 'sometimes|array|min:1';
            $rules['start_date'] = 'sometimes|date';
            $rules['end_date'] = 'sometimes|date';
        }

        return $rules;
    }

    public function messages(): array {
        return [
            'questions.*.options.required_if' => 'Multiple choice questions must have at least two options.',
            'questions.*.options.*.string' => 'Each option for multiple choice questions must be a string.',
        ];
    }
}
