<?php

namespace App\Http\Requests\Api;

use Illuminate\Foundation\Http\FormRequest;

class InvoiceRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array {
        $rules = [
            "company_id" => "required|exists:companies,id",
            "client_id" => "required|exists:clients,id",

            "date" => "required|date",
            "amount" => "required|numeric|between:0,99999999.99",
            "status" => "sometimes|string|max:50",
            "file" => "sometimes|file|mimes:pdf|max:2048",

            "invoice_details" => "nullable|array",
            "invoice_details.*.service_id" => "required|exists:services,id",
            "invoice_details.*.amount" => "required|numeric|between:0,99999999.99",
            "invoice_details.*.quantity" => "required|integer|min:0|max:8388607",
        ];

        if ($this->routeIs("invoices.update")) {
            $rules["company_id"] = "sometimes|exists:companies,id";
            $rules["client_id"] = "sometimes|exists:clients,id";

            $rules["date"] = "sometimes|date";
            $rules["amount"] = "sometimes|numeric|between:0,99999999.99";
            $rules["file"] = $this->hasFile("file")
                ? "nullable|file|mimes:jpg,jpeg,png,pdf|max:2048"
                : "nullable|string|max:100";

            $rules["invoice_details.*.amount"] = "sometimes|numeric|between:0,99999999.99";
            $rules["invoice_details.*.quantity"] = "sometimes|integer|min:0|max:8388607";
        }

        return $rules;
    }
}
