<?php

namespace App\Http\Requests\Api;

use Illuminate\Foundation\Http\FormRequest;

class IssueRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array {
        $rules = [
            "company_id" => "required|exists:companies,id",
            "project_id" => "required|exists:projects,id",
            "user_id" => "required|exists:users,id",

            "name" => "required|string|max:100",
            "technology" => "required|string|max:100",
            "solutions" => "required|string",
            "code" => "nullable|string",
            "references" => "nullable|string",
            "file" => "nullable|file|mimes:jpg,jpeg,png,pdf|max:2048"
        ];

        if ($this->routeIs("issues.update")) {
            $rules["company_id"] = "sometimes|exists:companies,id";
            $rules["project_id"] = "sometimes|exists:projects,id";
            $rules["user_id"] = "sometimes|exists:users,id";

            $rules["name"] = "sometimes|string|max:100";
            $rules["technology"] = "sometimes|string|max:100";
            $rules["solutions"] = "sometimes|string";
            $rules["file"] = $this->hasFile("file")
                ? "nullable|file|mimes:jpg,jpeg,png,pdf|max:2048"
                : "nullable|string|max:100";
        }

        return $rules;
    }
}
