<?php

namespace App\Http\Requests\Api;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class LeadRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array {
        $rules = [
            "company_id" => "required|exists:companies,id",
            "service_id" => "required|exists:services,id",

            "name" => "required|string|max:100",
            "email" => "required|email|unique:leads|max:255",
            "phone_number" => "required|string|max:20",
            'source' => "required|string|max:100",
            'status' => "nullable|string|max:50",
            "last_call" => "nullable|string",
        ];

        if ($this->routeIs("leads.update")) {
            $leadId = $this->route("lead");

            $rules["company_id"] = "sometimes|exists:companies,id";
            $rules["service_id"] = "sometimes|exists:services,id";

            $rules["name"] = "sometimes|string|max:100";
            $rules["email"] = [
                "sometimes",
                "email",
                "max:255",
                Rule::unique('leads')->ignore($leadId)
            ];
            $rules["phone_number"] = "sometimes|string|max:20";
            $rules["source"] = "sometimes|string|max:100";
        }

        return $rules;
    }
}
