<?php

namespace App\Http\Requests\Api;

use Illuminate\Foundation\Http\FormRequest;

class PaymentRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array {
        $rules = [
            "company_id" => "required|exists:companies,id",
            "invoice_id" => "required|exists:invoices,id",

            "amount" => "required|numeric|between:0,99999999.99",
            "date" => "required|date",
            "type" => "required|string:50",
            "payment_mode" => "required|string:50",
            "file" => "sometimes|file|mimes:pdf|max:2048"
        ];

        if ($this->routeIs("payments.update")) {
            $rules["company_id"] = "sometimes|exists:companies,id";
            $rules["invoice_id"] = "sometimes|exists:invoices,id";

            $rules["amount"] = "sometimes|numeric|between:0,99999999.99";
            $rules["date"] = "sometimes|date";
            $rules["type"] = "sometimes|string:50";
            $rules["payment_mode"] = "sometimes|string:50";

            $rules["file"] = $this->hasFile("file")
                ? "nullable|file|mimes:jpg,jpeg,png,pdf|max:2048"
                : "nullable|string|max:100";
        }

        return $rules;
    }
}
