<?php

namespace App\Http\Requests\Api;

use Illuminate\Foundation\Http\FormRequest;

class ProjectRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array {
        $rules = [
            "company_id" => "required|exists:companies,id",
            "service_id" => "required|exists:services,id",
            "client_id" => "required|exists:clients,id",
            "invoice_id" => "nullable|exists:invoices,id",

            "name" => "required|string|max:100",
            "start_date" => "required|date",
            "end_date" => "nullable|date",
            "cost" => "sometimes|numeric|between:0,99999999.99",
            "test_url" => "nullable|url|max:255",
            "live_url" => "nullable|url|max:255",
            "db_design_url" => "nullable|url|max:255",
            "payment_received" => "nullable|numeric|between:0,99999999.99",
            "payment_received_percentage" => "nullable|numeric",

            // Allow multiple users to be assigned
            'user_ids' => 'nullable|array',
            // Validate each user_id exists in the users table
            'user_ids.*' => 'exists:users,id',

            'project_resources' => 'nullable|array',
            'project_resources.*.id' => 'sometimes|exists:project_resources,id',
            'project_resources.*.resource_document' => 'nullable|string',
            'project_resources.*.build' => 'nullable|string',
            'project_resources.*.apk' => 'nullable|string',
            'project_resources.*.api_collection' => 'nullable|url',
        ];

        if ($this->routeIs("projects.update")) {
            $rules["company_id"] = "sometimes|exists:companies,id";
            $rules["service_id"] = "sometimes|exists:services,id";
            $rules["client_id"] = "sometimes|exists:clients,id";

            $rules["name"] = "sometimes|string|max:100";
            $rules["start_date"] = "sometimes|date";
        }

        return $rules;
    }
}
