<?php

namespace App\Http\Requests\Api;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class ProposalRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array {
        $rules = [
            "company_id" => "required|exists:companies,id",
            "service_id" => "required|exists:services,id",

            "name" => "required|string|max:100",
            "email" => "required|string|unique:proposals|max:255",
            "phone_number" => "required|string|max:20",
            'quotation_amount' => "required|numeric|between:0,99999999.99",
            'sent_date' => "nullable|date",
            'status' => "nullable|string|max:50",
            "file" => "nullable|file|mimes:jpg,jpeg,png,pdf|max:2048"
        ];

        if ($this->routeIs("proposals.update")) {
            $proposalId = $this->route("proposal");

            $rules["company_id"] = "sometimes|exists:companies,id";
            $rules["service_id"] = "sometimes|exists:services,id";

            $rules["name"] = "sometimes|string|max:100";
            $rules["email"] = [
                "sometimes",
                "email",
                "max:255",
                Rule::unique('proposals')->ignore($proposalId)
            ];
            $rules["phone_number"] = "sometimes|string|max:20";
            $rules["quotation_amount"] = "sometimes|numeric|between:0,99999999.99";
            $rules["file"] = $this->hasFile("file")
                ? "file|mimes:jpg,jpeg,png,pdf|max:2048"
                : "nullable|string|max:100";
        }

        return $rules;
    }
}
