<?php

namespace App\Http\Requests\Api;

use App\Models\Question;
use Illuminate\Foundation\Http\FormRequest;

class QuestionRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array {
        $questionTypes = Question::TYPES; // ['mcq', 'text']
        $rules = [
            "feedback_form_id" => "required|exists:feedback_forms,id",
            "question" => "required|string|max:255",
            "type" => "required|in:".implode(",", $questionTypes),
            // required if type is mcq
            "options" => "required_if:type,".$questionTypes[0]."|array|min:2",
            // each option should be a string
            "options.*" => "string"
        ];

        if ($this->routeIs("questions.update")) {
            $rules["feedback_form_id"] = "sometimes|exists:feedback_forms,id";
            $rules["question"] = "sometimes|string|max:255";
            $rules["type"] = "sometimes|in:".implode(",", $questionTypes);

            // only required if type is multiple_choice
            $rules["options"] = "sometimes|required_if:type,".$questionTypes[0]."|array|min:2";
        }

        return $rules;
    }
}
