<?php

namespace App\Http\Requests\Api;

use Illuminate\Foundation\Http\FormRequest;

class ServiceRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array {
        $rules = [
            // relations
            "company_id" => "required|exists:companies,id",

            "name" => "required|string|max:100",
            "hourly_cost" => "required|numeric|between:1,99999999.99",
            "description" => "sometimes|string",

            // file uploads
            "image" => "sometimes|file|mimes:jpg,jpeg,png|max:2048"
        ];

        if ($this->routeIs("services.update")) {
            $rules["company_id"] = "sometimes|exists:companies,id";
            $rules["name"] = "sometimes|string|max:255";
            $rules["hourly_cost"] = "sometimes|numeric|between:1,99999999.99";
            $rules["image"] = $this->hasFile("image")
                ? "sometimes|file|mimes:jpg,jpeg,png,pdf|max:2048"
                : "nullable|string|max:100";
        }

        return $rules;
    }
}
