<?php

namespace App\Http\Requests\Api;

use Illuminate\Foundation\Http\FormRequest;

class TaskRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array {
        $rules = [
            "company_id" => "required|exists:companies,id",
            "project_id" => "required|exists:projects,id",
            "amc_task_id" => "nullable|exists:amc_tasks,id",

            "name" => "required|string|max:100",
            "start_date" => "required|date",
            "end_date" => "nullable|date",
            // TODO: We can omit bth the fields
            "start_time" => "required|date_format:H:i:s",
            "end_time" => "nullable|date_format:H:i:s",
            "type" => "nullable|string|max:100",
            "priority" => "nullable|string|max:50",
            "status" => "nullable|string|max:50",

            // Allow multiple users to be assigned
            'user_ids' => 'nullable|array',
            // Validate each user_id exists in the users table
            'user_ids.*' => 'exists:users,id',
        ];

        if ($this->routeIs("tasks.update")) {
            $rules["company_id"] = "sometimes|exists:companies,id";
            $rules["project_id"] = "sometimes|exists:projects,id";
            $rules["amc_task_id"] = "nullable|exists:amc_tasks,id";

            $rules["name"] = "sometimes|string|max:100";
            $rules["start_date"] = "sometimes|date";
            $rules["start_time"] = "sometimes|date_format:H:i:s";
        }

        return $rules;
    }
}
