<?php

namespace App\Http\Requests\Api;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class UserRequest extends FormRequest
{
    public function authorize(): bool {
        return true;
    }

    public function rules(): array {
        $rules = [
            // relations
            "company_id" => "sometimes|required_if_accepted:role_id,2,3|exists:companies,id",
            "role_id" => "required|exists:roles,id",

            "name" => "required|string|max:100",
            "designation" => "sometimes|string|max:50",
            "phone_number" => "required|string|max:20",
            "email" => "required|email|unique:users|max:255",
            "password" => "required|string|max:255",
            // "password_confirmation" => "required|string",
            "alternative_number" => "nullable|string|max:20",
            "home_number" => "nullable|string|max:20",
            "leaves_left" => "sometimes|numeric|between:0,100",
            "employee_points" => "nullable|numeric",
            "reimbursement" => "nullable|numeric|between:0,99999999.99",
            "joining_date" => "nullable|date",
            "dob" => "required|date",

            // file uploads
            "offer_letter" => "nullable|file|mimes:pdf|max:2048",
            "aadhar_front" => "nullable|file|mimes:jpg,jpeg,png,pdf|max:2048",
            "aadhar_back" => "nullable|file|mimes:jpg,jpeg,png,pdf|max:2048",
            "pan" => "nullable|file|mimes:jpg,jpeg,png,pdf|max:2048",
            "prev_company_experience_letter" => "nullable|file|mimes:pdf|max:2048",
            "relieving_letter" => "nullable|file|mimes:pdf|max:2048",
        ];

        if ($this->routeIs("users.update")) {
            $userId = $this->route("user");

            $rules["role_id"] = "sometimes|exists:roles,id";
            $rules["name"] = "sometimes|string|max:100";
            $rules["email"] = [
                "sometimes",
                "email",
                "max:255",
                Rule::unique('users')->ignore($userId)
            ];
            $rules["mobile_no"] = "sometimes|string|max:20";
            $rules["password"] = "sometimes|string|max:255";

            $rules["aadhar_front"] = $this->hasFile("aadhar_front")
                ? "sometimes|file|mimes:jpg,jpeg,png,pdf|max:2048"
                : "nullable|string|max:100";
            $rules["aadhar_back"] = $this->hasFile("aadhar_back")
                ? "sometimes|file|mimes:jpg,jpeg,png,pdf|max:2048"
                : "nullable|string|max:100";
            $rules["offer_latter"] = $this->hasFile("offer_latter")
                ? "sometimes|file|mimes:jpg,jpeg,png,pdf|max:2048"
                : "nullable|string|max:100";
            $rules["pan"] = $this->hasFile("pan")
                ? "sometimes|file|mimes:jpg,jpeg,png,pdf|max:2048"
                : "nullable|string|max:100";
            $rules["prev_company_experience_letter"] = $this->hasFile("prev_company_experience_letter")
                ? "sometimes|file|mimes:jpg,jpeg,png,pdf|max:2048"
                : "nullable|string|max:100";
            $rules["relieving_latter"] = $this->hasFile("relieving_latter")
                ? "sometimes|file|mimes:jpg,jpeg,png,pdf|max:2048"
                : "nullable|string|max:100";
        }

        return $rules;
    }
}
