<?php

namespace App\Http\Resources;

use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class ClientResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @return array<string, mixed>
     */
    public function toArray(Request $request): array {
        return [
            "id" => $this->id,

            "company_id" => $this->company_id,

            "name" => $this->name,
            "company_name" => $this->company_name,
            "billing_name" => $this->billing_name,
            "email" => $this->email,
            "gst_no" => $this->gst_no,
            "dob" => $this->dob,
            "latitude" => $this->latitude,
            "longitude" => $this->longitude,

            // relations
            "company" => new CompanyResource($this->whenLoaded("company")),
            "projects" => ProjectResource::collection($this->whenLoaded("projects")),
            "meetings" => MeetingResource::collection($this->whenLoaded("meetings")),
            "amcs" => AmcResource::collection($this->whenLoaded("amcs")),
            "invoices" => InvoiceResource::collection($this->whenLoaded("invoices")),
            "credentials" => CredentialResource::collection($this->whenLoaded("credentials")),
            "follow_ups" => FollowUpResource::collection($this->whenLoaded("followUps")),

            // timestamps
            "created_at" => $this->created_at,
            "updated_at" => $this->updated_at,
        ];
    }
}
