<?php

namespace App\Http\Resources;

use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class CompanyResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @return array<string, mixed>
     */
    public function toArray(Request $request): array {
        return [
            "id" => $this->id,

            "name" => $this->name,
            "founder_name" => $this->founder_name,
            "gst_no" => $this->gst_no,
            "address" => $this->address,
            "logo" => $this->logo,
            "sign" => $this->sign,
            "stamp" => $this->stamp,
            "anniversary_date" => $this->anniversary_date,
            "bank_name" => $this->bank_name,
            "account_no" => $this->account_no,
            "branch_name" => $this->branch_name,
            "ifsc_code" => $this->ifsc_code,

            // relations
            "services" => ServiceResource::collection($this->whenLoaded("services")),
            "clients" => ClientResource::collection($this->whenLoaded("clients")),
            "projects" => ProjectResource::collection($this->whenLoaded("projects")),
            "notices" => NoticeResource::collection($this->whenLoaded("notices")),
            "amcs" => AmcResource::collection($this->whenLoaded("amcs")),
            "invoices" => InvoiceResource::collection($this->whenLoaded("invoices")),
            "payments" => PaymentResource::collection($this->whenLoaded("payments")),
            "users" => UserResource::collection($this->whenLoaded("users")),
            "tasks" => TaskResource::collection($this->whenLoaded("tasks")),
            "meetings" => MeetingResource::collection($this->whenLoaded("meetings")),
            "notifications" => NotificationResource::collection($this->whenLoaded("notifications")),
            "complaints" => ComplaintResource::collection($this->whenLoaded("complaints")),
            "issues" => IssueResource::collection($this->whenLoaded("issues")),
            "expenses" => ExpenseResource::collection($this->whenLoaded("expenses")),
            "vendors" => VendorResource::collection($this->whenLoaded("vendors")),
            "proposals" => ProposalResource::collection($this->whenLoaded("proposals")),
            "leads" => LeadResource::collection($this->whenLoaded("leads")),
            "task_logs" => TaskLogResource::collection($this->whenLoaded("taskLogs")),
            "feedback_forms" => FeedbackFormResource::collection($this->whenLoaded("feedbackForms")),

            // timestamps
            "created_at" => $this->created_at,
            "updated_at" => $this->updated_at,
        ];
    }
}
