<?php

namespace App\Http\Resources;

use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class ProjectResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @return array<string, mixed>
     */
    public function toArray(Request $request): array {
        return [
            "id" => $this->id,

            "company_id" => $this->company_id,
            "service_id" => $this->service_id,
            "client_id" => $this->client_id,
            "invoice_id" => $this->invoice_id,

            "name" => $this->name,
            "start_date" => $this->start_date,
            "end_date" => $this->end_date,
            "cost" => $this->cost,
            "test_url" => $this->test_url,
            "live_url" => $this->live_url,
            "db_design_url" => $this->db_design_url,
            "payment_received" => $this->payment_received,
            "payment_received_percentage" => $this->payment_received_percentage,

            // relations
            "company" => new CompanyResource($this->whenLoaded("company")),
            "service" => new ServiceResource($this->whenLoaded("service")),
            "client" => new ClientResource($this->whenLoaded("client")),
            "invoice" => new InvoiceResource($this->whenLoaded("invoice")),
            "tasks" => TaskResource::collection($this->whenLoaded("tasks")),
            "project_resources" => ProjectResResource::collection($this->whenLoaded("projectResources")),
            "users" => UserResource::collection($this->whenLoaded("users")),
            "credentials" => CredentialResource::collection($this->whenLoaded("credentials")),
            "issues" => IssueResource::collection($this->whenLoaded("issues")),
            "task_logs" => TaskLogResource::collection($this->whenLoaded("taskLogs")),

            // timestamps
            "created_at" => $this->created_at,
            "updated_at" => $this->updated_at,
        ];
    }
}
