<?php

namespace App\Http\Resources;

use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class UserResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @return array<string, mixed>
     */
    public function toArray(Request $request): array {
        return [
            "id" => $this->id,

            // foreign keys
            "company_id" => $this->company_id,
            "role_id" => $this->role_id,

            //  user data
            "name" => $this->name,
            "email" => $this->email,
            "phone_number" => $this->phone_number,
            "designation" => $this->designation,
            "alternative_number" => $this->alternative_number,
            "home_number" => $this->home_number,
            "leaves_left" => $this->leaves_left,
            "employee_points" => $this->employee_points,
            "reimbursement" => $this->reimbursement,
            "joining_date" => $this->joining_date,
            "dob" => $this->dob,

            // files
            "profile" => $this->profile,
            "offer_letter" => $this->offer_letter,
            "aadhar_front" => $this->aadhar_front,
            "aadhar_back" => $this->aadhar_back,
            "pan" => $this->pan,
            "prev_company_experience_letter" => $this->prev_company_experience_letter,
            "relieving_letter_letter" => $this->relieving_letter_letter,

            // one-to-one relations
            "role" => new RoleResource($this->whenLoaded("role")),
            "company" => new CompanyResource($this->whenLoaded("company")),

            // one-to-many relations
            "permissions" => PermissionResource::collection($this->whenLoaded("permissions")),
            "notifications" => NotificationResource::collection($this->whenLoaded("notifications")),
            "leaves" => LeaveResource::collection($this->whenLoaded("leaves")),
            "attendances" => AttendanceResource::collection($this->whenLoaded("attendances")),
            "breaks" => BreakResource::collection($this->whenLoaded("breaks")),
            "complaints" => ComplaintResource::collection($this->whenLoaded("complaints")),
            "ratings" => RatingResource::collection($this->whenLoaded("ratings")),
            "expenses" => ExpenseResource::collection($this->whenLoaded("expenses")),
            "issues" => IssueResource::collection($this->whenLoaded("issues")),
            "answers" => AnswerResource::collection($this->whenLoaded("answers")),

            // many-to-many relations
            "meetings" => MeetingResource::collection($this->whenLoaded("meetings")),
            "projects" => ProjectResource::collection($this->whenLoaded("projects")),
            "tasks" => TaskResource::collection($this->whenLoaded("tasks")),

            "created_at" => $this->created_at,
            "updated_at" => $this->updated_at,
        ];
    }
}

