<?php

namespace App\Mail;

use App\Models\Project;
use Illuminate\Bus\Queueable;
use Illuminate\Mail\Mailable;
use Illuminate\Mail\Mailables\Content;
use Illuminate\Mail\Mailables\Envelope;
use Illuminate\Queue\SerializesModels;

class ProjectCreatedMail extends Mailable
{
    use Queueable, SerializesModels;

    /**
     * Create a new message instance.
     */
    public function __construct(protected Project $project) {
        //
    }

    /**
     * Get the message envelope.
     */
    public function envelope(): Envelope {
        return new Envelope(
            subject: 'A new project has been created!',
        );
    }

    /**
     * Get the message content definition.
     */
    public function content(): Content {
        return new Content(
            markdown: 'mail.project-created',
            with: [
                'name' => $this->project->name,
                'clientName' => $this->project->client->name ?? 'N/A', // Client's name
                'startDate' => $this->project->start_date->format('d-m-Y') ?? 'N/A', // Formatted start date
                'endDate' => optional($this->project->end_date)->format('d-m-Y') ?? 'N/A', // Formatted end date
                'cost' => $this->project->cost, // Project cost
                'testUrl' => $this->project->test_url ?? 'Not available', // Test URL
                'liveUrl' => $this->project->live_url ?? 'Not available', // Live URL
            ]
        );
    }

    /**
     * Get the attachments for the message.
     *
     * @return array<int, \Illuminate\Mail\Mailables\Attachment>
     */
    public function attachments(): array {
        return [];
    }
}
