<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Dyrynda\Database\Support\CascadeSoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class Amc extends Model
{
    use HasFactory, Filterable, SoftDeletes, CascadeSoftDeletes;

    protected $fillable = [
        "company_id",
        "service_id",
        "client_id",

        "start_date",
        "end_date",
        "amount",
        "invoice_copy",
        "mail_subject",
    ];

    protected $casts = [
        "start_date" => "date",
        "end_date" => "date",
    ];

    protected array $cascadeDeletes = ["amcTasks", "amcTimelines"];

    public function company(): BelongsTo {
        return $this->belongsTo(Company::class);
    }

    public function service(): BelongsTo {
        return $this->belongsTo(Service::class);
    }

    public function client(): BelongsTo {
        return $this->belongsTo(Client::class);
    }

    public function amcTasks(): HasMany {
        return $this->hasMany(AmcTask::class);
    }

    public function amcTimelines(): HasMany {
        return $this->hasMany(AmcTimeline::class);
    }

}
