<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Dyrynda\Database\Support\CascadeSoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class AmcTask extends Model
{
    use HasFactory, Filterable, SoftDeletes, CascadeSoftDeletes;

    protected $fillable = [
        "amc_id",

        "name",
        "priority",
        "status",
        "deadline",
    ];

    protected array $cascadeDeletes = [
        "tasks", "taskLogs"
    ];

    protected $casts = [
        "deadline" => "date",
    ];

    public function amc(): BelongsTo {
        return $this->belongsTo(Amc::class);
    }

    public function tasks(): HasMany {
        return $this->hasMany(Task::class);
    }

    public function taskLogs(): HasMany {
        return $this->hasMany(TaskLog::class);
    }
}
