<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Dyrynda\Database\Support\CascadeSoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Notifications\Notifiable;

class Client extends Model
{
    use HasFactory, Filterable, Notifiable, SoftDeletes, CascadeSoftDeletes;

    protected $fillable = [
        "company_id",

        "name",
        "company_name",
        "billing_name",
        "email",
        "phone_number",
        "gst_no",
        "dob",
        "latitude",
        "longitude",
    ];

    protected array $cascadeDeletes = [
        "projects", "meetings", "amcs", "invoices", "credentials", "followUps"
    ];

    protected $casts = [
        "dob" => "date",
    ];

    public function company(): BelongsTo {
        return $this->belongsTo(Company::class);
    }

    public function projects(): HasMany {
        return $this->hasMany(Project::class);
    }

    public function meetings(): HasMany {
        return $this->hasMany(Meeting::class);
    }

    public function amcs(): HasMany {
        return $this->hasMany(Amc::class);
    }

    public function invoices(): HasMany {
        return $this->hasMany(Invoice::class);
    }

    public function credentials(): HasMany {
        return $this->hasMany(Credential::class);
    }

    public function followUps(): HasMany {
        return $this->hasMany(FollowUp::class);
    }

}
