<?php

namespace App\Models;

use Dyrynda\Database\Support\CascadeSoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class Company extends Model
{
    use HasFactory, SoftDeletes, CascadeSoftDeletes;

    protected $fillable = [
        "name",
        "founder_name",
        "gst_no",
        "address",
        "anniversary_date",
        "bank_name",
        "account_no",
        "branch_name",
        "ifsc_code",
    ];

    protected $casts = [
        "anniversary_date" => "date"
    ];

    protected array $cascadeDeletes = [
        "services", "clients", "projects", "payments", "notices", "amcs", "invoices",
        "users", "tasks", "meetings", "notifications", "issues", "complaints",
        "expenses", "vendors", "proposals", "leads", "taskLogs", "feedbackForms",
    ];

    public function services(): HasMany {
        return $this->hasMany(Service::class);
    }

    public function clients(): HasMany {
        return $this->hasMany(Client::class);
    }

    public function projects(): HasMany {
        return $this->hasMany(Project::class);
    }

    public function payments(): HasMany {
        return $this->hasMany(Payment::class);
    }

    public function notices(): HasMany {
        return $this->hasMany(Notice::class);
    }

    public function amcs(): HasMany {
        return $this->hasMany(Amc::class);
    }

    public function invoices(): HasMany {
        return $this->hasMany(Invoice::class);
    }

    public function users(): HasMany {
        return $this->hasMany(User::class);
    }

    public function tasks(): HasMany {
        return $this->hasMany(Task::class);
    }

    public function meetings(): HasMany {
        return $this->hasMany(Meeting::class);
    }

    public function notifications(): HasMany {
        return $this->hasMany(Notification::class);
    }

    public function issues(): HasMany {
        return $this->hasMany(Issue::class);
    }

    public function complaints(): HasMany {
        return $this->hasMany(Complaint::class);
    }

    public function expenses(): HasMany {
        return $this->hasMany(Expense::class);
    }

    public function vendors(): HasMany {
        return $this->hasMany(Vendor::class);
    }

    public function proposals(): HasMany {
        return $this->hasMany(Proposal::class);
    }

    public function leads(): HasMany {
        return $this->hasMany(Lead::class);
    }

    public function taskLogs(): HasMany {
        return $this->hasMany(TaskLog::class);
    }

    public function feedbackForms(): HasMany {
        return $this->hasMany(FeedbackForm::class);
    }
}
