<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\SoftDeletes;

class Expense extends Model
{
    use HasFactory, Filterable, SoftDeletes;

    protected $fillable = [
        "company_id",
        "expense_type_id",
        "vendor_id",
        "user_id",

        "name",
        "amount",
        "is_approved",
    ];

    protected $casts = [
        "amount" => "decimal",
        "is_approved" => "boolean",
    ];

    public function company(): BelongsTo {
        return $this->belongsTo(Company::class);
    }

    public function expenseType(): BelongsTo {
        return $this->belongsTo(ExpenseType::class);
    }

    public function vendor(): BelongsTo {
        return $this->belongsTo(Vendor::class);
    }

    public function spentBy(): BelongsTo {
        return $this->belongsTo(User::class, "user_id");
    }
}
