<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Dyrynda\Database\Support\CascadeSoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class FeedbackForm extends Model
{
    use HasFactory, Filterable, SoftDeletes, CascadeSoftDeletes;

    protected $fillable = [
        "company_id",

        "title",
        "description",
        "start_date",
        "end_date"
    ];

    protected array $cascadeDeletes = [
        "questions", "answers" // TODO: what about employees
    ];

    protected $casts = [
        "start_date" => "date",
        "end_date" => "date"
    ];

    public function company(): BelongsTo {
        return $this->belongsTo(Company::class);
    }

    public function questions(): HasMany {
        return $this->hasMany(Question::class);
    }

    public function answers(): HasMany {
        return $this->hasMany(Answer::class);
    }

    public function employees(): BelongsToMany {
        return $this->belongsToMany(User::class, "employee_feedback")
            ->withPivot("submitted_at");
    }
}
