<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Dyrynda\Database\Support\CascadeSoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class Invoice extends Model
{
    use HasFactory, Filterable, SoftDeletes, CascadeSoftDeletes;

    protected $fillable = [
        "company_id",
        "client_id",

        "date",
        "amount",
        "status",
    ];

    protected array $cascadeDeletes = [
        "invoiceDetails", "payments"
    ];

    protected $casts = [
        "date" => "date",
    ];

    public function company(): BelongsTo {
        return $this->belongsTo(Company::class);
    }

    public function client(): BelongsTo {
        return $this->belongsTo(Client::class);
    }

    public function invoiceDetails(): HasMany {
        return $this->hasMany(InvoiceDetail::class);
    }

    public function payments(): HasMany {
        return $this->hasMany(Payment::class);
    }

}
