<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Dyrynda\Database\Support\CascadeSoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class Lead extends Model
{
    use HasFactory, Filterable, SoftDeletes, CascadeSoftDeletes;

    protected $fillable = [
        "company_id",
        "service_id",

        'name',
        'email',
        'phone_number',
        'source',
        'status',
        "last_call",
    ];

    protected array $cascadeDeletes = ["followUps"];

    public function company(): BelongsTo {
        return $this->belongsTo(Company::class);
    }

    public function service(): BelongsTo {
        return $this->belongsTo(Service::class);
    }

    public function followUps(): HasMany {
        return $this->hasMany(FollowUp::class);
    }
}
