<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class Meeting extends Model
{
    use HasFactory, Filterable, SoftDeletes;

    protected $fillable = [
        "company_id",
        "client_id",

        "date_time",
        "is_client",
        "link",
        "agenda",
        "outcome",
        "status",
        "expected_duration",
        "final_duration",
    ];

    protected $casts = [
        "date_time" => "datetime",
        "is_client" => "boolean",
        "expected_duration" => "datetime:H:i:s",
        "final_duration" => "datetime:H:i:s",
    ];

    // TODO: what about users cascade delete

    public function company(): BelongsTo {
        return $this->belongsTo(Company::class);
    }

    public function client(): BelongsTo {
        return $this->belongsTo(Client::class);
    }

    // many-to-many relation
    public function users(): BelongsToMany {
        return $this->belongsToMany(User::class, "meeting_user");
    }
}
