<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Dyrynda\Database\Support\CascadeSoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class Project extends Model
{
    use HasFactory, Filterable, SoftDeletes, CascadeSoftDeletes;

    protected $fillable = [
        "company_id",
        "service_id",
        "client_id",
        "invoice_id",

        "name",
        "start_date",
        "end_date",
        "cost",
        "test_url",
        "live_url",
        "db_design_url",
        "payment_received",
        "payment_received_percentage",
    ];

    protected $casts = [
        'start_date' => 'date',
        'end_date' => 'date',
        "payment_received_percentage" => "integer",
    ];

    protected array $cascadeDeletes = [
        "projectResources", "tasks", "taskLogs", "credentials", "issues"
    ];

    // TODO: what about users cascade delete

    public function company(): BelongsTo {
        return $this->belongsTo(Company::class);
    }

    public function service(): BelongsTo {
        return $this->belongsTo(Service::class);
    }

    public function client(): BelongsTo {
        return $this->belongsTo(Client::class);
    }

    public function invoice(): BelongsTo {
        return $this->belongsTo(Invoice::class);
    }

    public function projectResources(): HasMany {
        return $this->hasMany(ProjectResource::class);
    }

    public function tasks(): HasMany {
        return $this->hasMany(Task::class);
    }

    public function taskLogs(): HasMany {
        return $this->hasMany(TaskLog::class);
    }

    public function credentials(): HasMany {
        return $this->hasMany(Credential::class);
    }

    public function issues(): HasMany {
        return $this->hasMany(Issue::class);
    }

    // many-to-many relation
    public function users(): BelongsToMany {
        return $this->belongsToMany(User::class, "project_user");
    }
}
