<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Dyrynda\Database\Support\CascadeSoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class Question extends Model
{
    use HasFactory, Filterable, SoftDeletes, CascadeSoftDeletes;

    public const TYPES = ["mcq", "text"];

    protected $fillable = [
        "feedback_form_id",

        "question",
        "type",
        "options"
    ];

    protected array $cascadeDeletes = ["answers"];

    protected $casts = [
        "options" => "array",
    ];

    public function feedbackForm(): BelongsTo {
        return $this->belongsTo(FeedbackForm::class);
    }

    public function answers(): HasMany {
        return $this->hasMany(Answer::class);
    }
}
