<?php

namespace App\Models;

use Dyrynda\Database\Support\CascadeSoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class Service extends Model
{
    use HasFactory, SoftDeletes, CascadeSoftDeletes;

    protected $fillable = [
        "company_id",
        "name",
        "hourly_cost",
        "description",
    ];

    protected array $cascadeDeletes = [
        "projects", "amcs", "leads", "proposals", "vendors"
    ];

    protected $casts = [
    ];

    public function company(): BelongsTo {
        return $this->belongsTo(Company::class);
    }

    public function projects(): HasMany {
        return $this->hasMany(Project::class);
    }

    public function amcs(): HasMany {
        return $this->hasMany(Amc::class);
    }

    public function leads(): HasMany {
        return $this->hasMany(Lead::class);
    }

    public function proposals(): HasMany {
        return $this->hasMany(Proposal::class);
    }

    public function vendors(): HasMany {
        return $this->hasMany(Vendor::class);
    }
}
