<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class Task extends Model
{
    use HasFactory, Filterable, SoftDeletes;

    protected $fillable = [
        "company_id",
        "project_id",
        "amc_task_id",

        "name",
        "start_date",
        "end_date",
        "start_time",
        "end_time",
        "type",
        "priority",
        "status",
    ];

    protected $casts = [
        "start_date" => "date",
        "end_date" => "date",
        "start_time" => "datetime:H:i:s",
        "end_time" => "datetime:H:i:s",
    ];

    public function company(): BelongsTo {
        return $this->belongsTo(Company::class);
    }

    public function project(): BelongsTo {
        return $this->belongsTo(Project::class);
    }

    public function amcTask(): BelongsTo {
        return $this->belongsTo(AmcTask::class);
    }

    // many-to-many relation
    public function users(): BelongsToMany {
        return $this->belongsToMany(User::class, "task_user");
    }
}
