<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use Abbasudo\Purity\Traits\Filterable;
use Dyrynda\Database\Support\CascadeSoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;

class User extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable, Filterable, SoftDeletes, CascadeSoftDeletes;

    protected $fillable = [
        "company_id",
        "role_id",

        "name",
        "designation",
        "mobile_number",
        "email",
        "is_admin",
        "alternative_number",
        "home_number",
        "leaves_left",
        "employee_points",
        "reimbursement",
        "joining_date",
        "dob",
    ];

    protected $hidden = [
        "is_admin",
        'password',
        'remember_token',
    ];

    protected array $cascadeDeletes = [
        "notifications", "leaves", "ratings", "attendances", "breaks",
        "complaints", "expenses", "issues", "answers", "feedbacks",
        "permissions"
    ];

    public function role(): BelongsTo {
        return $this->belongsTo(Role::class);
    }

    public function company(): BelongsTo {
        return $this->belongsTo(Company::class);
    }

    public function permissions(): HasMany {
        return $this->hasMany(Permission::class);
    }

    public function notifications(): HasMany {
        return $this->hasMany(Notification::class);
    }

    public function leaves(): HasMany {
        return $this->hasMany(Leave::class);
    }

    public function ratings(): HasMany {
        return $this->hasMany(Rating::class);
    }

    public function attendances(): HasMany {
        return $this->hasMany(Attendance::class);
    }

    public function breaks(): HasMany {
        return $this->hasMany(EmployeeBreak::class);
    }

    public function complaints(): HasMany {
        return $this->hasMany(Complaint::class);
    }

    public function expenses(): HasMany {
        return $this->hasMany(Expense::class);
    }

    public function issues(): HasMany {
        return $this->hasMany(Issue::class);
    }

    public function answers(): HasMany {
        return $this->hasMany(Answer::class);
    }

    // many-to-many relation
    public function meetings(): BelongsToMany {
        return $this->belongsToMany(Meeting::class, "meeting_user");
    }

    // many-to-many relation
    public function projects(): BelongsToMany {
        return $this->belongsToMany(Project::class, "project_user");
    }

    // many-to-many relation
    public function tasks(): BelongsToMany {
        return $this->belongsToMany(Task::class, "task_user");
    }

    public function feedbacks(): BelongsToMany {
        return $this->belongsToMany(FeedbackForm::class, "employee_feedback")
            ->withPivot("submitted_at");
    }

    protected function casts(): array {
        return [
            'email_verified_at' => 'datetime',
            'password' => 'hashed',
            'is_admin' => "boolean",
            "leaves_left" => "integer",
            "employee_points" => "integer",
            "joining_date" => "date",
            "dob" => "date",
        ];
    }

}
