<?php

namespace Database\Factories;

use App\Models\User;
use Illuminate\Database\Eloquent\Factories\Factory;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

/**
 * @extends \Illuminate\Database\Eloquent\Factories\Factory<\App\Models\User>
 */
class UserFactory extends Factory
{
    /**
     * The current password being used by the factory.
     */
    protected static ?string $password;

    protected $model = User::class;

    /**
     * Define the model's default state.
     *
     * @return array<string, mixed>
     */
    public function definition(): array {
        return [
            "name" => $this->faker->name,
            "email" => fake()->unique()->safeEmail(),
            "email_verified_at" => now(),
            "password" => static::$password ?? Hash::make('password'),
            "remember_token" => Str::random(10),
            "designation" => "Software Developer",
            "phone_number" => $this->faker->phoneNumber,
            "alternative_number" => null,
            "home_number" => null,
            "leaves_left" => 85,
            "employee_points" => $this->faker->numberBetween(10, 200),
            "joining_date" => $this->faker->dateTimeThisDecade(),
            "dob" => $this->faker->dateTimeThisDecade,
        ];
    }

    /**
     * Indicate that the model's email address should be unverified.
     */
    public function unverified(): static {
        return $this->state(fn(array $attributes) => [
            'email_verified_at' => null,
        ]);
    }
}
