<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration {
    /**
     * Run the migrations.
     */
    public function up(): void {
        Schema::create('users', function (Blueprint $table) {
            $table->id();

            // foreign keys
            $table->foreignId("company_id")->nullable()->constrained("companies")
                ->cascadeOnDelete();
            $table->foreignId("role_id")->constrained("roles")
                ->cascadeOnDelete();

            $table->string('name', 100);
            $table->string('designation', 50)->nullable();
            $table->string('phone_number', 20);
            $table->string('email')->unique();
            $table->string('password');
            $table->boolean("is_admin")->default(false);

            $table->timestamp('email_verified_at')->nullable();
            $table->string('alternative_number', 20)->nullable();
            $table->string('home_number', 20)->nullable();
            $table->tinyInteger("leaves_left")->default(49);
            $table->smallInteger("employee_points")->default(0);
            $table->decimal("reimbursement", 10, 2)->default(0);
            $table->date("joining_date")->nullable();
            $table->date("dob");

            // file uploads (to store file names)
            $table->string("profile", 100)->nullable();
            $table->string("offer_letter", 100)->nullable();
            $table->string("aadhar_front", 100)->nullable();
            $table->string("aadhar_back", 100)->nullable();
            $table->string("pan", 100)->nullable();
            $table->string("prev_experience_letter", 100)->nullable();
            $table->string("relieving_letter", 100)->nullable();


            $table->rememberToken();
            $table->timestamps();
            $table->softDeletes();
        });

        Schema::create('password_reset_tokens', function (Blueprint $table) {
            $table->string('email')->primary();
            $table->string('token');
            $table->timestamp('created_at')->nullable();
        });

        Schema::create('sessions', function (Blueprint $table) {
            $table->string('id')->primary();
            $table->foreignId('user_id')->nullable()->index();
            $table->string('ip_address', 45)->nullable();
            $table->text('user_agent')->nullable();
            $table->longText('payload');
            $table->integer('last_activity')->index();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void {
        Schema::dropIfExists('users');
        Schema::dropIfExists('password_reset_tokens');
        Schema::dropIfExists('sessions');
    }
};
