<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration {
    /**
     * Run the migrations.
     */
    public function up(): void {
        Schema::create('projects', function (Blueprint $table) {
            $table->id();

            $table->foreignId("company_id")->constrained("companies")
                ->cascadeOnUpdate()->cascadeOnDelete();
            $table->foreignId("service_id")->constrained("services")
                ->cascadeOnUpdate()->cascadeOnDelete();
            $table->foreignId("client_id")->constrained("clients")
                ->cascadeOnUpdate()->cascadeOnDelete();
            $table->foreignId("invoice_id")->nullable()->constrained("invoices")
                ->cascadeOnUpdate()->cascadeOnDelete();

            $table->string("name", 100);
            $table->date("start_date");
            $table->date("end_date")->nullable();
            $table->decimal("cost", 10, 2)->nullable()->default(0);
            $table->string("test_url")->nullable();
            $table->string("live_url")->nullable();
            $table->string("db_design_url")->nullable();
            $table->decimal("payment_received", 10, 2)->default(0);
            $table->unsignedTinyInteger("payment_received_percentage")->default(0);

            $table->timestamps();
            $table->softDeletes();
        });

        Schema::create("project_user", function (Blueprint $table) {
            $table->id();

            $table->foreignId("project_id")->constrained("projects")
                ->cascadeOnDelete();
            $table->foreignId("user_id")->constrained("users")
                ->cascadeOnDelete();

            $table->timestamps();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void {
        Schema::dropIfExists('project_user');
        Schema::dropIfExists('projects');
    }
};
