<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration {
    /**
     * Run the migrations.
     */
    public function up(): void {
        Schema::create('meetings', function (Blueprint $table) {
            $table->id();

            $table->foreignId("company_id")->constrained("companies")
                ->cascadeOnUpdate()->cascadeOnDelete();
            $table->foreignId("client_id")->nullable()->constrained("clients")
                ->cascadeOnUpdate()->cascadeOnDelete();

            $table->dateTime("date_time");
            $table->string("link", 50)->nullable();
            $table->string("agenda", 100)->nullable();
            $table->string("outcome", 100)->nullable();
            $table->string("status", 50)->nullable();
            // TODO: ask what should be datatype
            $table->time("expected_duration")->nullable();
            $table->time("final_duration")->nullable();
            $table->boolean("is_client")->default(false);

            $table->timestamps();
            $table->softDeletes();
        });

        // pivot table
        Schema::create("meeting_user", function (Blueprint $table) {
            $table->id();

            $table->foreignId("meeting_id")->constrained("meetings")
                ->cascadeOnDelete();
            $table->foreignId("user_id")->constrained("users")
                ->cascadeOnDelete();
            $table->unique(["meeting_id", "user_id"]);

            $table->timestamps();

        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void {
        Schema::dropIfExists('meeting_user');
        Schema::dropIfExists('meetings');
    }
};
