<?php

use App\Http\Controllers\Api\V1\AmcController;
use App\Http\Controllers\Api\V1\AmcTaskController;
use App\Http\Controllers\Api\V1\AmcTimelineController;
use App\Http\Controllers\Api\V1\AttendanceController;
use App\Http\Controllers\Api\V1\AuthController;
use App\Http\Controllers\Api\V1\BreakController;
use App\Http\Controllers\Api\V1\CallLogController;
use App\Http\Controllers\Api\V1\ClientsController;
use App\Http\Controllers\Api\V1\CommandController;
use App\Http\Controllers\Api\V1\CompanyController;
use App\Http\Controllers\Api\V1\ComplaintController;
use App\Http\Controllers\Api\V1\CredentialController;
use App\Http\Controllers\Api\V1\DatabaseController;
use App\Http\Controllers\Api\V1\ExpenseController;
use App\Http\Controllers\Api\V1\ExpenseTypeController;
use App\Http\Controllers\Api\V1\FeedbackFormController;
use App\Http\Controllers\Api\V1\FollowUpController;
use App\Http\Controllers\Api\V1\HolidayController;
use App\Http\Controllers\Api\V1\InvoiceController;
use App\Http\Controllers\Api\V1\IssueController;
use App\Http\Controllers\Api\V1\LeadController;
use App\Http\Controllers\Api\V1\LeaveController;
use App\Http\Controllers\Api\V1\MeetingController;
use App\Http\Controllers\Api\V1\NoticeController;
use App\Http\Controllers\Api\V1\NotificationController;
use App\Http\Controllers\Api\V1\PageController;
use App\Http\Controllers\Api\V1\PaymentController;
use App\Http\Controllers\Api\V1\PermissionController;
use App\Http\Controllers\Api\V1\ProjectController;
use App\Http\Controllers\Api\V1\ProposalController;
use App\Http\Controllers\Api\V1\RatingController;
use App\Http\Controllers\Api\V1\RoleController;
use App\Http\Controllers\Api\V1\ServiceController;
use App\Http\Controllers\Api\V1\TaskController;
use App\Http\Controllers\Api\V1\TaskLogController;
use App\Http\Controllers\Api\V1\UserController;
use App\Http\Controllers\Api\V1\VendorController;
use App\Http\Controllers\Api\V1\VendorTransactionController;
use Illuminate\Support\Facades\Route;

Route::prefix("v1")->group(function () {
    // unprotected auth routes
    Route::post("sign-up", [AuthController::class, "signUp"])->name("sign-up");
    Route::post("sign-in", [AuthController::class, "signIn"])->name("sign-in");

    Route::middleware("auth:sanctum")
        ->group(function () {
            // protected auth routes
            Route::get("users/profile", [UserController::class, "profile"])->name("users.profile");
            Route::post("forgot-password", [AuthController::class, "forgotPassword"])->name("forgot-password");
            Route::post("update-password", [AuthController::class, "updatePassword"])->name("update-password");
            Route::delete("logout", [AuthController::class, "logout"])->name("logout");

            //  protected resource routes
            Route::apiResources([
                "roles" => RoleController::class,
                "companies" => CompanyController::class,
                "services" => ServiceController::class,
                "clients" => ClientsController::class,
                "pages" => PageController::class,
                "users" => UserController::class,
                "users.permissions" => PermissionController::class,
                "ratings" => RatingController::class,
                "attendances" => AttendanceController::class,
                "breaks" => BreakController::class,
                "invoices" => InvoiceController::class,
                // "invoice-details" => InvoiceDetailController::class,
                "payments" => PaymentController::class,
                "projects" => ProjectController::class,
                // "project-resources" => ProjectResourceController::class,
                "credentials" => CredentialController::class,
                "amcs" => AmcController::class,
                "amc-tasks" => AmcTaskController::class,
                "amc-timelines" => AmcTimelineController::class,
                "proposals" => ProposalController::class,
                "leads" => LeadController::class,
                "follow-ups" => FollowUpController::class,
                "notifications" => NotificationController::class,
                "tasks" => TaskController::class,
                "task-logs" => TaskLogController::class,
                "meetings" => MeetingController::class,
                "notices" => NoticeController::class,
                "leaves" => LeaveController::class,
                "complaints" => ComplaintController::class,
                "vendors" => VendorController::class,
                "vendor-transactions" => VendorTransactionController::class,
                "expense-types" => ExpenseTypeController::class,
                "expenses" => ExpenseController::class,
                "feedback-forms" => FeedbackFormController::class,
                // "questions" => QuestionController::class,
                // "answers" => AnswerController::class,
                "issues" => IssueController::class,
                "holidays" => HolidayController::class,
                "call-logs" => CallLogController::class,
            ], ["parameters" => ["leaves" => "leave"]]); // set explicitly because laravel converts as leaves => leaf

            Route::post("feedback-forms/{feedback_form}/submit",
                [FeedbackFormController::class, "submit"])->name("feedback-forms.submit");
        });

    Route::get("companies", [CompanyController::class, "index"])->name("companies.index");
    Route::get("roles", [RoleController::class, "index"])->name("roles.index");
    Route::patch("users/{user}/permissions", [PermissionController::class, "updateMany"]);

    Route::post("database", DatabaseController::class);
});
